@@ -1,5 +1,4 @@
-/* Time-stamp: <2005-06-17 22:25:30 jcs>
-|
+/*
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
 | 
@@ -24,12 +23,12 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: clientserver.c,v 1.11 2005/06/17 13:30:02 jcsjcs Exp $
+|  $Id$
 */
 
 #include "config.h"
 #include "clientserver.h"
-#include "md5.h"
+#include "sha1.h"
 #include "misc.h"
 #include "display_itdb.h"
 #include "prefs.h"
@@ -106,8 +105,9 @@ static gboolean socket_used ()
 	    if (connect(csock, (struct sockaddr *)server,
 			sizeof(struct sockaddr_un)) != -1)
 	    {
-		if (write(csock, SOCKET_TEST, strlen(SOCKET_TEST)) == 
-		    strlen (SOCKET_TEST))
+		size_t socket_test_len = strlen(SOCKET_TEST);
+		if (write(csock, SOCKET_TEST, socket_test_len) == 
+		    (ssize_t) socket_test_len)
 		    result = TRUE;
 	    }
 	    close(csock);
@@ -135,13 +135,13 @@ static gboolean register_playcount (gchar *file)
 	    {
 		if (flock (fd, LOCK_EX) == 0)
 		{
-		    gchar *md5 = md5_hash_on_filename (file, TRUE);
+		    gchar *sha1 = sha1_hash_on_filename (file, TRUE);
 		    write (fd, SOCKET_PLYC, strlen (SOCKET_PLYC));
-		    if (md5) write (fd, md5, strlen (md5));
+		    if (sha1) write (fd, sha1, strlen (sha1));
 		    write (fd, " ", 1);
 		    write (fd, file, strlen (file));
 		    write (fd, "\n", 1);
-		    g_free (md5);
+		    g_free (sha1);
 		}
 		else
 		{
@@ -270,7 +270,7 @@ void server_shutdown (void)
    running instance of gtkpod and transfer the filename, or write the
    name to ~/.gtkpod/offline_playcounts.
    Return value: TRUE on success, FALSE if a non-recoverable error
-   occured */
+   occurred */
 gboolean client_playcount (gchar *file)
 {
     if (socket_used ())
@@ -290,7 +290,8 @@ gboolean client_playcount (gchar *file)
 		{
 		    gchar *buf = g_strdup_printf ("%s%s",
 						  SOCKET_PLYC, file);
-		    if (write(csock, buf, strlen(buf)) != strlen (buf))
+		    size_t buf_len = strlen(buf);
+		    if (write(csock, buf, buf_len) != (ssize_t) buf_len)
 		    {
 			fprintf (stderr, "Error communicating to server. Playcount registered in offline database.\n");
 			register_playcount (file);
@@ -310,4 +311,15 @@ gboolean client_playcount (gchar *file)
 }
 
 
+/* print out the "sha1" hash of a filename <file> */
+gboolean print_sha1_hash (gchar *file)
+{
+    if (file && *file)
+    {
+	gchar *hash = sha1_hash_on_filename (file, TRUE);
+	if (hash) fprintf (stdout, "%s\n", hash);
+	g_free (hash);
+    }
+    return TRUE;
+}
 
