@@ -1,7 +1,6 @@
-/* Time-stamp: <2006-06-29 20:41:31 jcs>
-|
+/*
 |  Copyright (C) 2003 Corey Donohoe <atmos at atmos dot org>
-|  Copyright (C) 2003-2005 Jorg Schuler <jcsjcs at users sourceforge net>
+|  Copyright (C) 2003-2007 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
 | 
 |  URL: http://www.gtkpod.org/
@@ -25,7 +24,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: context_menus.c,v 1.66 2006/06/29 11:46:16 jcsjcs Exp $
+|  $Id$
 */
 
 #ifdef HAVE_CONFIG_H
@@ -33,8 +32,10 @@
 #endif
 
 #include "itdb.h"
+#include "info.h"
 #include "details.h"
 #include "display.h"
+#include "display_itdb.h"
 #include "file.h"
 #include "misc.h"
 #include "misc_track.h"
@@ -42,6 +43,8 @@
 #include "tools.h"
 #include "repository.h"
 #include "syncdir.h"
+#include "display_coverart.h"
+#include "display_photo.h"
 
 #define LOCALDEBUG 0
 
@@ -55,7 +58,10 @@ typedef enum {
     CM_PL = 0,
     CM_ST,
     CM_TM,
-    CM_NUM
+    CM_NUM,
+    CM_CAD,
+    CM_PH_AV,
+    CM_PH_IV
 } CM_type;
 
 
@@ -77,7 +83,6 @@ do_special(GtkWidget *w, gpointer data)
 	gchar *mp;
 	Track *tr = gl->data;
 	g_return_if_fail (tr);
-
 	g_object_get (tr->itdb->device, "mount-point", &mp, NULL);
 	printf ("mountpoint: %s\n", mp);
 	g_free (mp);
@@ -165,6 +170,18 @@ edit_details_entries(GtkMenuItem *mi, gpointer data)
 	details_edit (selected_tracks);
 }
 
+/*
+ * display the dialog with the full size cd artwork cover
+ * @mi - the menu item selected
+ * @data - Ignored, should be NULL
+ */
+static void
+display_track_artwork(GtkMenuItem *mi, gpointer data)
+{
+	if (selected_tracks)
+		coverart_display_big_artwork (selected_tracks);
+}
+
 /*
  * update_entries - update the entries currently selected
  * @mi - the menu item selected
@@ -302,6 +319,8 @@ static void eject_ipod (GtkMenuItem *mi, gpointer data)
     g_return_if_fail (eitdb->itdb_imported == TRUE);
 
     gp_eject_ipod (itdb);
+    /* Set the coverart display based on the selected playlist */
+    coverart_display_update(TRUE);
 }
 
 
@@ -314,6 +333,169 @@ static void save_changes (GtkMenuItem *mi, gpointer data)
 
 
 
+
+/* ------------------------------------------------------------
+
+      Copying selected item(s) to target destination
+
+   ------------------------------------------------------------ */
+
+
+/*
+ * Copy the selected playlist to a specified itdb.
+ */
+void
+copy_playlist_to_target_itdb (Playlist     *pl,
+			      iTunesDB     *t_itdb)
+{
+    Playlist	*pl_n;
+    GList	*addtracks = NULL;
+    g_return_if_fail (pl);
+    g_return_if_fail (t_itdb);
+    if (pl->itdb != t_itdb)
+    {
+	addtracks = export_trackglist_when_necessary (pl->itdb,
+						      t_itdb,
+						      pl->members);
+	if (addtracks || !pl->members)
+	{
+	    pl_n = gp_playlist_add_new(t_itdb, pl->name, FALSE, -1);
+	    add_trackglist_to_playlist (pl_n, addtracks);
+	    gtkpod_statusbar_message (_("Copied \"%s\" playlist to %s"),
+				      pl->name, (itdb_playlist_mpl (t_itdb))->name);
+	}
+	g_list_free (addtracks);
+	addtracks = NULL;
+    }
+    else
+    {
+	pl_n = itdb_playlist_duplicate (pl);
+	g_return_if_fail (pl_n);
+	gp_playlist_add (t_itdb, pl_n, -1);
+    }
+}
+
+
+/*
+ * Copy selected tracks to a specified itdb.
+ */
+void
+copy_tracks_to_target_itdb (GList        *tracks,
+			    iTunesDB     *t_itdb)
+{
+    GList       *addtracks = NULL;
+    Track	*first = tracks->data;
+    Playlist    *mpl;
+    gint        n;
+
+    g_return_if_fail(tracks);
+    g_return_if_fail(t_itdb);
+
+    mpl = itdb_playlist_mpl (t_itdb);
+    g_return_if_fail(mpl);
+
+    addtracks = export_trackglist_when_necessary (first->itdb, t_itdb, tracks);
+
+    if (addtracks)
+    {
+	add_trackglist_to_playlist (mpl, addtracks);
+	n = g_list_length (addtracks);
+	gtkpod_statusbar_message (ngettext ("Copied %d track to '%s'",
+					    "Copied %d tracks to '%s'", n),
+				  n, mpl->name);
+	g_list_free (addtracks);
+	addtracks = NULL;
+    }
+}
+
+
+void
+copy_playlist_to_target_playlist (Playlist     *pl,
+				  Playlist     *t_pl)
+{
+    GList	*addtracks = NULL;
+    Playlist    *t_mpl;
+
+    g_return_if_fail (pl);
+    g_return_if_fail (t_pl);
+
+    t_mpl = itdb_playlist_mpl (t_pl->itdb);
+    g_return_if_fail(t_mpl);
+
+    addtracks = export_trackglist_when_necessary (pl->itdb,
+						  t_pl->itdb,
+						  pl->members);
+    if (addtracks || !pl->members)
+    {
+	add_trackglist_to_playlist (t_pl, addtracks);
+	gtkpod_statusbar_message (_("Copied '%s' playlist to '%s' in '%s'"),
+				  pl->name, t_pl->name, t_mpl->name);
+	g_list_free(addtracks);
+	addtracks = NULL;
+    }
+}
+
+
+
+void
+copy_tracks_to_target_playlist (GList        *tracks,
+				Playlist     *t_pl)
+{
+    GList	*addtracks = NULL;
+    Track	*first;
+    Playlist    *mpl;
+    gint        n;
+
+    g_return_if_fail (tracks);
+    g_return_if_fail (t_pl);
+    g_return_if_fail (t_pl->itdb);
+
+    mpl = itdb_playlist_mpl (t_pl->itdb);
+    g_return_if_fail(mpl);
+
+    if (tracks)
+    {
+	first = tracks->data;
+	g_return_if_fail (first);
+	addtracks = export_trackglist_when_necessary (first->itdb, t_pl->itdb, tracks);
+	add_trackglist_to_playlist (t_pl, addtracks);
+    }
+    n = g_list_length (addtracks);
+    gtkpod_statusbar_message (ngettext ("Copied %d track to '%s' in '%s'",
+					"Copied %d tracks to %s in '%s'", n),
+			      n, t_pl->name, mpl->name);
+    g_list_free (addtracks);
+    addtracks = NULL;
+}
+
+
+
+static void copy_selected_to_target_itdb (GtkMenuItem *mi, gpointer *userdata)
+{
+    iTunesDB *t_itdb = *userdata;
+    g_return_if_fail (t_itdb);
+    if (selected_playlist)
+	copy_playlist_to_target_itdb (selected_playlist, t_itdb);
+    else if (selected_entry)
+	copy_tracks_to_target_itdb (selected_entry->members, t_itdb);
+    else if (selected_tracks)
+	copy_tracks_to_target_itdb (selected_tracks, t_itdb);
+}
+
+
+static void copy_selected_to_target_playlist (GtkMenuItem *mi, gpointer *userdata)
+{
+    Playlist *t_pl = *userdata;
+    g_return_if_fail (t_pl);
+    if (selected_playlist)
+	copy_playlist_to_target_playlist (selected_playlist, t_pl);
+    else if (selected_entry)
+	copy_tracks_to_target_playlist (selected_entry->members, t_pl);
+    else if (selected_tracks)
+	copy_tracks_to_target_playlist (selected_tracks, t_pl);
+}
+
+
 /* Attach a menu item to your context menu */
 /* @m - the GtkMenu we're attaching to
  * @str - a gchar* with the menu label
@@ -321,7 +503,11 @@ static void save_changes (GtkMenuItem *mi, gpointer data)
  * @func - the callback for when the item is selected (or NULL)
  * @mi - the GtkWidget we're gonna hook into the menu
  */
-GtkWidget *hookup_mi (GtkWidget *m, gchar *str, gchar *stock, GCallback func, gpointer userdata)
+GtkWidget *hookup_mi (GtkWidget *m,
+		      const gchar *str,
+		      const gchar *stock,
+		      GCallback func,
+		      gpointer userdata)
 {
     GtkWidget *mi;
 
@@ -362,6 +548,77 @@ GtkWidget *add_separator (GtkWidget *m)
 }
 
 
+static GtkWidget *add_copy_selected_to_target_itdb (GtkWidget *menu,
+						    const gchar *title)
+{
+    GtkWidget *mi;
+    GtkWidget *sub;
+    GtkWidget *pl_mi;
+    GtkWidget *pl_sub;
+    GList *itdbs;
+    GList *db;
+    struct itdbs_head *itdbs_head;
+    iTunesDB *itdb;
+    const gchar *stock_id = NULL;
+    Playlist *pl;
+
+  
+    g_return_val_if_fail (gtkpod_window, NULL);
+    itdbs_head = g_object_get_data (G_OBJECT (gtkpod_window),
+                                    "itdbs_head");
+
+    mi = hookup_mi (menu, title,
+		    GTK_STOCK_COPY,
+		    NULL, NULL);
+    sub = gtk_menu_new ();
+    gtk_widget_show (sub);
+    gtk_menu_item_set_submenu (GTK_MENU_ITEM (mi), sub);
+
+    for (itdbs=itdbs_head->itdbs; itdbs; itdbs=itdbs->next)
+	    {
+		itdb = itdbs->data;
+		ExtraiTunesDBData *eitdb=itdb->userdata;
+		if (itdb->usertype & GP_ITDB_TYPE_LOCAL)
+		{
+			stock_id = GTK_STOCK_HARDDISK;
+		}
+		else
+		{
+		    if (eitdb->itdb_imported)
+		    {
+		        stock_id = GTK_STOCK_CONNECT;
+		    }
+		    else
+		    {
+		        stock_id = GTK_STOCK_DISCONNECT;
+		    }
+		}
+		pl_mi = hookup_mi (sub, _(itdb_playlist_mpl(itdb)->name),
+				   stock_id, NULL, NULL);
+		pl_sub = gtk_menu_new ();
+		gtk_widget_show (pl_sub);
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (pl_mi), pl_sub);
+		hookup_mi (pl_sub, _(itdb_playlist_mpl(itdb)->name),
+			   stock_id, G_CALLBACK(copy_selected_to_target_itdb), &itdbs->data);
+		add_separator(pl_sub);
+		for (db=itdb->playlists; db; db=db->next)
+		{
+			pl=db->data;
+			if (!itdb_playlist_is_mpl (pl))
+			{
+				if (pl->is_spl)
+					stock_id = GTK_STOCK_PROPERTIES;
+				else
+					stock_id = GTK_STOCK_JUSTIFY_LEFT;
+				hookup_mi(pl_sub, _(pl->name), stock_id, 
+				G_CALLBACK(copy_selected_to_target_playlist) , &db->data);
+			}
+		}
+	    }
+    return mi;
+}
+
+
 static GtkWidget *add_play_now (GtkWidget *menu)
 {
     return hookup_mi (menu, _("Play Now"), GTK_STOCK_CDROM,
@@ -475,6 +732,20 @@ static GtkWidget *add_edit_ipod_properties (GtkWidget *menu)
 		      G_CALLBACK (edit_properties), NULL);
 }
 
+static GtkWidget *add_edit_repository_properties (GtkWidget *menu)
+{
+    return hookup_mi (menu,  _("Edit Repository Properties"),
+		      GTK_STOCK_PREFERENCES,
+		      G_CALLBACK (edit_properties), NULL);
+}
+
+static GtkWidget *add_edit_playlist_properties (GtkWidget *menu)
+{
+    return hookup_mi (menu,  _("Edit Playlist Properties"),
+		      GTK_STOCK_PREFERENCES,
+		      G_CALLBACK (edit_properties), NULL);
+}
+
 static GtkWidget *add_edit_track_details (GtkWidget *menu)
 {
     return hookup_mi (menu,  _("Edit Track Details"),
@@ -482,6 +753,34 @@ static GtkWidget *add_edit_track_details (GtkWidget *menu)
 		      G_CALLBACK (edit_details_entries), NULL);
 }
 
+static GtkWidget *add_display_big_coverart (GtkWidget *menu)
+{
+    const gchar *icon;
+/* gets defined in gtk+ V2.8, but we only require V2.6 */
+#ifndef GTK_STOCK_FULLSCREEN
+#define GTK_STOCK_FULLSCREEN "gtk-fullscreen"
+#endif
+    if (gtk_check_version (2,8,0) == NULL)
+    {
+	icon = GTK_STOCK_FULLSCREEN;
+    }
+    else
+    {
+	icon = NULL;
+    }
+
+    return hookup_mi (menu,  _("View Full Size Artwork"),
+		      icon,
+		      G_CALLBACK (display_track_artwork), NULL);	
+}
+
+static GtkWidget *add_get_cover_from_file (GtkWidget *menu)
+{
+		return hookup_mi (menu, _("Select Cover From File"),
+					GTK_STOCK_FLOPPY,
+					G_CALLBACK (coverart_set_cover_from_file), NULL);
+}
+
 static GtkWidget *add_check_ipod_files (GtkWidget *menu)
 {
     /* FIXME */
@@ -591,13 +890,42 @@ static GtkWidget *add_special (GtkWidget *menu)
 }
 #endif
 
-static GtkWidget *add_edit_playlist_properties (GtkWidget *menu)
+GtkWidget *gphoto_menuitem_remove_album_from_db_item(GtkWidget *menu)
 {
-    return hookup_mi (menu,  _("Edit Playlist Properties"),
-		      GTK_STOCK_PREFERENCES,
-		      G_CALLBACK (edit_properties), NULL);
+	return hookup_mi (
+			menu, 
+			_("Remove Album"), 
+			GTK_STOCK_DELETE, 
+			G_CALLBACK (gphoto_remove_album_from_database), 
+			NULL);
 }
 
+GtkWidget *gphoto_menuitem_remove_photo_from_album_item(GtkWidget *menu)
+{
+	GtkWidget *mitem = hookup_mi (
+			menu, 
+			_("Remove Photo"),
+			GTK_STOCK_DELETE, 
+			G_CALLBACK (gphoto_remove_selected_photos_from_album), 
+			NULL);
+	
+	if (gphoto_get_selected_photo_count() == 0)
+		gtk_widget_set_sensitive (mitem, FALSE);
+	else
+		gtk_widget_set_sensitive (mitem, TRUE);
+	
+	return mitem;
+}
+
+GtkWidget *gphoto_menuitem_rename_photoalbum_item(GtkWidget *menu)
+{
+	return hookup_mi (
+			menu, 
+			_("Rename Album"),
+			GTK_STOCK_DELETE, 
+			G_CALLBACK (gphoto_rename_selected_album), 
+			NULL);
+}
 
 void create_context_menu (CM_type type)
 {
@@ -651,13 +979,15 @@ void create_context_menu (CM_type type)
 			add_delete_including_tracks (menu);
 			add_delete_but_keep_tracks (menu);
 		    }
+		    add_copy_selected_to_target_itdb (menu,
+						      _("Copy selected playlist to..."));
 		    add_separator (menu);
 		    add_edit_track_details (menu);
 		    if (pl->is_spl)
 		    {
 			add_edit_smart_playlist (menu);
 		    }
-		    if (itdb_playlist_is_mpl (pl) || pl->is_spl)
+		    if (itdb_playlist_is_mpl (pl))
 		    {
 			add_edit_ipod_properties (menu);
 		    }
@@ -698,13 +1028,22 @@ void create_context_menu (CM_type type)
 		    add_delete_including_tracks_harddisk (menu);
 		    add_delete_but_keep_tracks (menu);
 		}
+		add_copy_selected_to_target_itdb (menu,
+						  _("Copy selected playlist to..."));
 		add_separator (menu);
 		add_edit_track_details (menu);
 		if (pl->is_spl)
 		{
 		    add_edit_smart_playlist (menu);
 		}
-		add_edit_playlist_properties (menu);
+		if (itdb_playlist_is_mpl (pl))
+		{
+		    add_edit_repository_properties (menu);
+		}
+		else
+		{
+		    add_edit_playlist_properties (menu);
+		}
 		add_save_changes (menu);
 	    }
 	    break;
@@ -742,6 +1081,8 @@ void create_context_menu (CM_type type)
 		    add_delete_from_playlist (menu);
 		}
 	    }
+	    add_copy_selected_to_target_itdb (menu,
+					      _("Copy selected track(s) to..."));
 	    add_separator (menu);
 	    add_edit_track_details (menu);
 #if LOCALDEBUG
@@ -753,6 +1094,18 @@ void create_context_menu (CM_type type)
 	    }
 #endif
 	    break;
+	case CM_CAD:
+			add_get_cover_from_file (menu);
+			add_display_big_coverart (menu);
+			add_edit_track_details (menu);
+			break;
+	case CM_PH_AV:
+			gphoto_menuitem_remove_album_from_db_item (menu);
+			gphoto_menuitem_rename_photoalbum_item (menu);
+			break;
+	case CM_PH_IV:
+			gphoto_menuitem_remove_photo_from_album_item (menu);
+			break;
 	case CM_NUM:
 	    g_return_if_reached ();
 	}
@@ -790,6 +1143,54 @@ tm_context_menu_init(void)
 	create_context_menu (CM_TM);
     }
 }
+
+/**
+ * cad_context_menu_init - initialize the right click menu for coverart display 
+ */
+void
+cad_context_menu_init(void)
+{
+    if (widgets_blocked) return;
+    
+    selected_entry = NULL; 
+    selected_playlist = NULL;
+    selected_tracks = NULL;
+    active_itdb = gp_get_selected_itdb ();
+    entry_inst = -1;
+    
+     if (selected_tracks) g_list_free (selected_tracks);
+    	selected_tracks = g_list_copy (coverart_get_displayed_tracks());
+    	
+    if(selected_tracks)
+			create_context_menu (CM_CAD);
+}
+
+/**
+ * photo_context_menu_init - initialize the right click menu for photo management display 
+ */
+void
+gphoto_context_menu_init (gint component)
+{
+    if (widgets_blocked) return;
+    
+    selected_entry = NULL; 
+    selected_playlist = NULL;
+    selected_tracks = NULL;
+    active_itdb = gp_get_selected_itdb ();
+    entry_inst = -1;
+    
+     if (selected_tracks) g_list_free (selected_tracks);
+
+     switch (component)
+     {
+    	 case GPHOTO_ALBUM_VIEW:
+    		 create_context_menu (CM_PH_AV);
+    		 break;
+    	 case GPHOTO_ICON_VIEW:
+    		 create_context_menu (CM_PH_IV);
+     }
+}
+
 /**
  * pm_context_menu_init - initialize the right click menu for playlists 
  */
@@ -797,7 +1198,7 @@ void
 pm_context_menu_init(void)
 {
     if (widgets_blocked) return;
-
+    
     pm_stop_editing (TRUE);
 
     if (selected_tracks)  g_list_free (selected_tracks);
@@ -805,13 +1206,16 @@ pm_context_menu_init(void)
     selected_entry = NULL;
     entry_inst = -1;
     selected_playlist = pm_get_selected_playlist();
+    
     active_itdb = gp_get_selected_itdb ();
+
     if(selected_playlist)
     {
 	selected_tracks = g_list_copy (selected_playlist->members);
 	create_context_menu (CM_PL);
     }
 }
+
 /**
  * st_context_menu_init - initialize the right click menu for sort tabs 
  * FIXME: This needs to be hooked in.
