@@ -23,7 +23,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: date_parser.h 270 2003-09-23 19:57:15Z samc $
+|  $Id$
 */
 
 #ifndef __DATE_PARSER_H__
@@ -35,7 +35,7 @@
 
 #include <gtk/gtk.h>
 #include <time.h>
-#include <display.h>
+#include "display.h"
 
 /* Set to "1" if debugging output is desired */
 #define DP_DEBUG 0
