@@ -23,7 +23,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: details.c 2149 2008-11-08 09:38:35Z jcsjcs $
+|  $Id$
 */
 
 /* This file provides functions for the details window */
@@ -199,6 +199,24 @@ static void details_checkbutton_toggled (GtkCheckButton *button,
     details_get_item (detail, item, FALSE);
 }
 
+static gboolean details_scale_changed (GtkRange     *scale,
+				       GtkScrollType scroll,
+				       gdouble       value,
+				       Detail       *detail)
+{
+    T_item item;
+
+    g_return_val_if_fail (scale, FALSE);
+
+    item = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (scale),
+					       "details_item"));
+    
+    g_return_val_if_fail ((item > 0) && (item < T_ITEM_NUM), FALSE);
+
+    details_get_item (detail, item, FALSE);
+
+    return FALSE;
+}
 
 static void details_combobox_changed (GtkComboBox *combobox,
 					 Detail *detail)
@@ -735,7 +753,6 @@ static void details_setup_widget (Detail *detail, T_item item)
     case T_PLAYCOUNT:
     case T_BPM:
     case T_RATING:
-    case T_VOLUME:
     case T_SOUNDCHECK:
     case T_CD_NR:
     case T_TRACK_NR:
@@ -765,6 +782,13 @@ static void details_setup_widget (Detail *detail, T_item item)
 			  G_CALLBACK (details_text_changed),
 			  detail);
 	break;
+    case T_VOLUME:
+        buf = g_strdup_printf ("details_scale_%d", item);
+        w = gtkpod_xml_get_widget (detail->xml, buf);
+        g_signal_connect (w, "change-value",
+        		  G_CALLBACK (details_scale_changed),
+        		  detail);
+	break;
     case T_COMPILATION:
     case T_TRANSFERRED:
     case T_CHECKED:
@@ -817,7 +841,7 @@ static void details_set_item (Detail *detail, Track *track, T_item item)
     GtkTextBuffer *tb;
     GtkWidget *w = NULL;
     gchar *text;
-    gchar *entry, *checkbutton, *textview, *combobox;
+    gchar *entry, *checkbutton, *textview, *combobox, *scale;
 
     g_return_if_fail (detail);
     g_return_if_fail ((item > 0) && (item < T_ITEM_NUM));
@@ -826,6 +850,7 @@ static void details_set_item (Detail *detail, Track *track, T_item item)
     checkbutton = g_strdup_printf ("details_checkbutton_%d", item);
     textview = g_strdup_printf ("details_textview_%d", item);
     combobox = g_strdup_printf ("details_combobox_%d", item);
+    scale = g_strdup_printf ("details_scale_%d", item);
 
     if (track != NULL)
     {
@@ -869,7 +894,6 @@ static void details_set_item (Detail *detail, Track *track, T_item item)
     case T_PLAYCOUNT:
     case T_BPM:
     case T_RATING:
-    case T_VOLUME:
     case T_SOUNDCHECK:
     case T_CD_NR:
     case T_TRACK_NR:
@@ -895,6 +919,17 @@ static void details_set_item (Detail *detail, Track *track, T_item item)
 	gtk_entry_set_text (GTK_ENTRY (w), text);
 	g_signal_handlers_unblock_by_func(w, details_text_changed,detail);
 	break;
+    case T_VOLUME:
+        w = gtkpod_xml_get_widget (detail->xml, scale);
+        if (track)
+	{
+	    gtk_range_set_value (GTK_RANGE (w), track->volume);
+        }
+        else
+	{
+            gtk_range_set_value (GTK_RANGE (w), 0.0);
+        }
+        break;
     case T_COMMENT:
     case T_DESCRIPTION:
     case T_LYRICS:
@@ -1001,6 +1036,7 @@ static void details_set_item (Detail *detail, Track *track, T_item item)
     g_free (textview);
     g_free (combobox);
     g_free (text);
+    g_free (scale);
 }
 
 
@@ -1013,7 +1049,7 @@ static void details_get_item (Detail *detail, T_item item,
 			      gboolean assumechanged)
 {
     GtkWidget *w = NULL;
-    gchar *entry, *checkbutton, *textview, *combobox;
+    gchar *entry, *checkbutton, *textview, *combobox, *scale;
     gboolean changed = FALSE;
     ExtraTrackData *etr;
     Track *track;
@@ -1030,6 +1066,7 @@ static void details_get_item (Detail *detail, T_item item,
     checkbutton = g_strdup_printf ("details_checkbutton_%d", item);
     textview = g_strdup_printf ("details_textview_%d", item);
     combobox = g_strdup_printf ("details_combobox_%d", item);
+    scale = g_strdup_printf ("details_scale_%d", item);
 
     switch (item)
     {
@@ -1049,7 +1086,6 @@ static void details_get_item (Detail *detail, T_item item,
     case T_PLAYCOUNT:
     case T_BPM:
     case T_RATING:
-    case T_VOLUME:
     case T_CD_NR:
     case T_TRACK_NR:
     case T_YEAR:
@@ -1118,6 +1154,18 @@ static void details_get_item (Detail *detail, T_item item,
 	    }
 	}
 	break;
+    case T_VOLUME:
+	if ((w = gtkpod_xml_get_widget (detail->xml, scale)))
+	{
+	    gdouble value = gtk_range_get_value (GTK_RANGE (w));
+	    gint32 new_volume = (gint32)value;
+	    if (track->volume != new_volume)
+	    {
+		track->volume = new_volume;
+		changed = TRUE;
+	    }
+	}
+	break;
     case T_COMMENT:
     case T_DESCRIPTION:
     case T_SUBTITLE:
@@ -1204,6 +1252,39 @@ static void details_get_item (Detail *detail, T_item item,
 		{
 		    track->mediatype = new_mediatype;
 		    changed = TRUE;
+          /* If audiobook or podcast is selected, update the skip when shuffling
+           * and remember playback position flags */
+          if (new_mediatype == ITDB_MEDIATYPE_AUDIOBOOK ||
+                new_mediatype == ITDB_MEDIATYPE_PODCAST ||
+                new_mediatype == (ITDB_MEDIATYPE_PODCAST|ITDB_MEDIATYPE_MOVIE))
+          {
+             gchar *buf;
+             GtkWidget *w2 = NULL;
+             if (track->remember_playback_position == 0)
+             {
+                buf = g_strdup_printf ("details_checkbutton_%d",
+                      T_REMEMBER_PLAYBACK_POSITION);
+                if ((w2 = gtkpod_xml_get_widget (detail->xml, buf)))
+                {
+                   track->remember_playback_position = 1;
+                   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w2),
+                         track->remember_playback_position);
+                }
+                g_free(buf);
+             }
+             if (track->skip_when_shuffling == 0)
+             {
+                buf = g_strdup_printf ("details_checkbutton_%d",
+                      T_SKIP_WHEN_SHUFFLING);
+                if ((w2 = gtkpod_xml_get_widget (detail->xml, buf)))
+                {
+                   track->remember_playback_position = 1;
+                   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w2),
+                         track->remember_playback_position);
+                }
+                g_free(buf);
+             }
+          }
 		}
 	    }
 	}
@@ -1254,6 +1335,7 @@ static void details_get_item (Detail *detail, T_item item,
     g_free (checkbutton);
     g_free (textview);
     g_free (combobox);
+    g_free (scale);
 
     details_update_buttons (detail);
 }
@@ -1470,7 +1552,7 @@ static void details_set_tracks (Detail *detail, GList *tracks)
 
     detail->itdb = ((Track *)tracks->data)->itdb;
 
-    detail->orig_tracks = glist_duplicate (tracks);
+    detail->orig_tracks = g_list_copy (tracks);
 
     /* Create duplicated list to work on until "Apply" is pressed */
     for (gl=g_list_last (tracks); gl; gl=gl->prev)
