@@ -1,5 +1,4 @@
-/* Time-stamp: <2007-12-13 01:02:57 jcs>
-|
+/*
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
 |
@@ -24,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display.c 1825 2007-12-13 13:28:20Z dforsi $
+|  $Id$
 */
 
 #ifdef HAVE_CONFIG_H
@@ -34,17 +33,19 @@
 #include "details.h"
 #include "display_private.h"
 #include "info.h"
+#include "infodlg.h"
 #include "ipod_init.h"
 #include "file_convert.h"
 #include "misc.h"
 #include "misc_track.h"
 #include "prefs.h"
-#include "prefs_window.h"
+#include "sort_window.h"
 #include "repository.h"
 #include "syncdir.h"
 #include "tools.h"
 #include <stdlib.h>
 #include <string.h>
+#include <cairo.h>
 #include <glib/gprintf.h>
 
 
@@ -87,6 +88,8 @@ void display_create (void)
     display_show_hide_toolbar ();
     /* Hide/Show tooltips */
     display_show_hide_tooltips ();
+    /* Hide/Show searchbar */
+    display_show_hide_searchbar ();
     /* change standard g_print () handler */
     g_set_print_handler ((GPrintFunc)gtkpod_warning);
 
@@ -104,7 +107,8 @@ void display_create (void)
     /* CAREFUL: must be done after calling ..._space_statusbar_init() */
     display_set_info_window_menu ();
     /* check if info window should be opened */
-    if (prefs_get_int("info_window"))  info_open_window ();
+    if (prefs_get_int("info_window"))
+		open_info_dialog ();
 }
 
 /* redisplay the entire display (playlists, sort tabs, track view) and
@@ -150,7 +154,7 @@ void display_cleanup (void)
 }
 
 
-/* make sure only suitable delete menu items are available */
+/* make sure only suitable menu items are available */
 void display_adjust_menus (void)
 {
     GtkWidget *delete;
@@ -168,6 +172,13 @@ void display_adjust_menus (void)
     edit3 = gtkpod_xml_get_widget (main_window_xml, "create_playlists_menu");
     edit4 = gtkpod_xml_get_widget (main_window_xml, "randomize_current_playlist_menu");
     edit5 = gtkpod_xml_get_widget (main_window_xml, "save_track_order_menu");
+
+#if 0
+    edit6 = gtkpod_xml_get_widget (main_window_xml, "add_files1");
+    edit7 = gtkpod_xml_get_widget (main_window_xml, "add_directory1");
+    edit8 = gtkpod_xml_get_widget (main_window_xml, "add_playlist1");
+#endif
+
     dtfpl = gtkpod_xml_get_widget (main_window_xml,
 				   "delete_selected_tracks_from_playlist");
     dtfip = gtkpod_xml_get_widget (main_window_xml,
@@ -197,6 +208,13 @@ void display_adjust_menus (void)
     espl = gtkpod_xml_get_widget (main_window_xml,
 				  "edit_smart_playlist");
 
+#if 0
+    tb_edit1 = gtkpod_xml_get_widget (main_window_xml, "add_files_button");
+    tb_edit2 = gtkpod_xml_get_widget (main_window_xml, "add_dirs_button");
+    tb_edit3 = gtkpod_xml_get_widget (main_window_xml, "add_PL_button");
+    tb_edit4 = gtkpod_xml_get_widget (main_window_xml, "new_PL_button");
+#endif
+
     pl = pm_get_selected_playlist ();
 
     if (pl == NULL)
@@ -362,6 +380,65 @@ void display_show_hide_toolbar (void)
     }
 }
 
+
+/* call gtkpod_tracks_statusbar_update() in order to redraw the
+ * statusbar, making GTK aware of the changed position for the resize
+ * grip. */
+gboolean display_redraw_statusbar (gpointer data)
+{
+    gtkpod_tracks_statusbar_update ();
+    return FALSE;
+}
+
+
+/* This is called (among others) when the window size changes.  This
+   hack needed to make GTK aware of the changed position for the
+   resize grip of the statusbar  */
+G_MODULE_EXPORT gboolean
+on_gtkpod_configure_event (GtkContainer *container,
+			   gpointer      user_data)
+{
+    g_idle_add (display_redraw_statusbar, NULL);
+    return FALSE;
+}
+
+
+
+/* make the search bar visible or hide it depending on the value set in
+ * the prefs
+ */
+void display_show_hide_searchbar (void)
+{
+	GtkWidget *upbutton = gtkpod_xml_get_widget (main_window_xml, "searchbar_up_button");
+	GtkWidget *searchbar = gtkpod_xml_get_widget (main_window_xml, "searchbar_hpanel");
+	GtkCheckMenuItem *mi = GTK_CHECK_MENU_ITEM (gtkpod_xml_get_widget (main_window_xml, "filterbar_menu"));
+	GtkStatusbar *sb = GTK_STATUSBAR (gtkpod_xml_get_widget (main_window_xml, "tracks_statusbar"));
+
+	g_return_if_fail (upbutton);
+	g_return_if_fail (searchbar);
+	g_return_if_fail (mi);
+	g_return_if_fail (sb);
+		
+	if (prefs_get_int ("display_search_entry"))
+	{
+		gtk_widget_show_all (searchbar);
+		gtk_widget_hide (upbutton);
+		gtk_check_menu_item_set_active (mi, TRUE);
+		gtk_statusbar_set_has_resize_grip (sb, TRUE);
+		/* hack needed to make GTK aware of the changed
+		   position for the resize grip */
+		g_idle_add (display_redraw_statusbar, NULL);
+	}
+	else
+	{		
+		gtk_widget_hide_all (searchbar);
+		gtk_widget_show (upbutton);
+		gtk_widget_set_sensitive (upbutton, TRUE);
+		gtk_check_menu_item_set_active (mi, FALSE);
+		gtk_statusbar_set_has_resize_grip (sb, FALSE);
+	}
+}
+
 /* Adjust the menu item status according on the value set in the
    prefs. */
 void display_set_info_window_menu (void)
@@ -419,8 +496,6 @@ void display_show_hide_tooltips (void)
     /* Show/Hide tooltips of the special sorttabs */
     st_show_hide_tooltips ();
     /* Show/Hide tooltips of the prefs window */
-    prefs_window_show_hide_tooltips ();
-    /* Show/Hide tooltips of the prefs window */
     sort_window_show_hide_tooltips ();
 }
 
@@ -443,12 +518,50 @@ void display_update_default_sizes (void)
     }
     tm_update_default_sizes ();
     st_update_default_sizes ();
-    prefs_window_update_default_sizes ();
-    info_update_default_sizes ();
+    info_dialog_update_default_sizes ();
     details_update_default_sizes ();
     file_convert_update_default_sizes ();
 }
 
+/**
+ * on_drawing_area_exposed:
+ *
+ * Callback for the drawing area. When the drwaing area is covered,
+ * resized, changed etc.. This will be called the draw() function is then
+ * called from this and the cairo redrawing takes place.
+ * 
+ * @draw_area: drawing area where al the cairo drawing takes place 
+ * @event: gdk expose event
+ * 
+ * Returns:
+ * boolean indicating whether other handlers should be run.
+ */
+static gboolean on_coverart_preview_dialog_exposed (GtkWidget *drawarea, GdkEventExpose *event, gpointer data)
+{
+	GdkPixbuf *image = data;
+	
+	/* Draw the image using cairo */
+		cairo_t *cairo_context;
+		
+		/* get a cairo_t */
+		cairo_context = gdk_cairo_create (drawarea->window);
+		/* set a clip region for the expose event */
+		cairo_rectangle (cairo_context,
+				event->area.x, event->area.y,
+				event->area.width, event->area.height);
+		cairo_clip (cairo_context);
+	
+		gdk_cairo_set_source_pixbuf (
+				cairo_context,
+				image,
+				0,
+				0);
+		cairo_paint (cairo_context);
+		
+		cairo_destroy (cairo_context);
+		return FALSE;
+}
+
 /**
  * display_image_dialog
  * 
@@ -464,18 +577,17 @@ void display_image_dialog (GdkPixbuf *image)
 	
 	GladeXML *preview_xml;
 	GtkWidget *dialog;
-	GtkWidget *canvasbox;
+	GtkWidget *drawarea;
 	GtkWidget *res_label;
 	GdkPixbuf *scaled = NULL;
 	gchar *text;
 		
-	preview_xml = glade_xml_new (xml_file, "coverart_preview_dialog", NULL);
-		
+	preview_xml = gtkpod_xml_new (xml_file, "coverart_preview_dialog");
 	dialog = gtkpod_xml_get_widget (preview_xml, "coverart_preview_dialog");
-	canvasbox = gtkpod_xml_get_widget (preview_xml, "coverart_preview_dialog_vbox");
+	drawarea = gtkpod_xml_get_widget (preview_xml, "coverart_preview_dialog_drawarea");
 	res_label = gtkpod_xml_get_widget (preview_xml, "coverart_preview_dialog_res_lbl");
 	g_return_if_fail (dialog);
-	g_return_if_fail (canvasbox);
+	g_return_if_fail (drawarea);
 	g_return_if_fail (res_label);
 		
 	/* Set the dialog parent */
@@ -485,9 +597,7 @@ void display_image_dialog (GdkPixbuf *image)
 	gint pixwidth = gdk_pixbuf_get_width (image);
 		
 	/* Set the resolution in the label */
-	gchar *resvalues = (gchar *) g_malloc (sizeof(gint) + (sizeof(gchar) * 3) + sizeof(gint));
-	g_sprintf (resvalues, "%d x %d", pixwidth, pixheight);
-	text = g_markup_printf_escaped (_("<b>Image Dimensions: %s</b>"), resvalues);
+	text = g_markup_printf_escaped (_("<b>Image Dimensions: %d x %d</b>"), pixwidth, pixheight);
 	gtk_label_set_markup (GTK_LABEL (res_label), text);
 	g_free (text);
 	
@@ -506,29 +616,17 @@ void display_image_dialog (GdkPixbuf *image)
 		pixheight = scrheight;
 		pixwidth = pixheight * ratio;
 	}
-		
-	GnomeCanvas *canvas;
-	canvas = GNOME_CANVAS (gnome_canvas_new());
-	gtk_widget_set_size_request ( GTK_WIDGET(canvas),
-			pixwidth,
-			pixheight);
 	
-	gnome_canvas_set_scroll_region (	canvas,
-																														0.0, 0.0, 
-																														pixwidth,
-																														pixheight);
-	GnomeCanvasItem *canvasitem;											
-	canvasitem = gnome_canvas_item_new(	gnome_canvas_root(canvas),
-																																			GNOME_TYPE_CANVAS_PIXBUF, NULL);
-		
-	scaled = gdk_pixbuf_scale_simple (image, pixwidth, pixheight, GDK_INTERP_NEAREST);
-		
-	/* Apply the image to the canvas */
-	gnome_canvas_item_set (	canvasitem,
-																							"pixbuf", scaled);
+	scaled = gdk_pixbuf_scale_simple (
+					image, 
+					pixwidth, 
+					pixheight, 
+					GDK_INTERP_BILINEAR);
 
-	gtk_box_pack_start_defaults (GTK_BOX(canvasbox), GTK_WIDGET (canvas));
-		
+	/* Set the draw area's minimum size */
+	gtk_widget_set_size_request  (drawarea, pixwidth, pixheight);
+	g_signal_connect (G_OBJECT (drawarea), "expose_event",  G_CALLBACK (on_coverart_preview_dialog_exposed), scaled);
+	
 	/* Display the dialog and block everything else until the
 	 * dialog is closed.
 	 */
@@ -536,11 +634,11 @@ void display_image_dialog (GdkPixbuf *image)
 	gtk_dialog_run (GTK_DIALOG(dialog));
 			
 	/* Destroy the dialog as no longer required */
-	gdk_pixbuf_unref (scaled);
+	
+	g_object_unref (scaled);
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
-
 /* Utility function: returns a copy of the tracks currently
    selected. This means:
 
@@ -722,7 +820,8 @@ void display_install_autoscroll_row_timeout (GtkWidget *widget)
 */
 
 
-void on_edit_details_selected_playlist (GtkMenuItem     *menuitem,
+G_MODULE_EXPORT void
+on_edit_details_selected_playlist (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
     Playlist *pl = pm_get_selected_playlist ();
@@ -737,7 +836,8 @@ void on_edit_details_selected_playlist (GtkMenuItem     *menuitem,
     }
 }
 
-void on_edit_details_selected_tab_entry (GtkMenuItem     *menuitem,
+G_MODULE_EXPORT void
+on_edit_details_selected_tab_entry (GtkMenuItem     *menuitem,
 					 gpointer         user_data)
 {
     gint inst = get_sort_tab_number (
@@ -755,7 +855,8 @@ void on_edit_details_selected_tab_entry (GtkMenuItem     *menuitem,
     }
 }
 
-void on_edit_details_selected_tracks (GtkMenuItem     *menuitem,
+G_MODULE_EXPORT void
+on_edit_details_selected_tracks (GtkMenuItem     *menuitem,
 				      gpointer         user_data)
 {
     GList *tracks = tm_get_selected_tracks ();
@@ -773,7 +874,7 @@ void on_edit_details_selected_tracks (GtkMenuItem     *menuitem,
 
 
 /* callback for "add new playlist" button */
-void
+G_MODULE_EXPORT void
 on_new_playlist_button                 (GtkButton       *button,
 					gpointer         user_data)
 {
@@ -791,7 +892,7 @@ on_new_playlist_button                 (GtkButton       *button,
 
 
 /* callback for "add new playlist" menu */
-void
+G_MODULE_EXPORT void
 on_new_playlist1_activate              (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -807,14 +908,7 @@ on_new_playlist1_activate              (GtkMenuItem     *menuitem,
     }
 }
 
-void
-on_edit_preferences_activate          (GtkMenuItem     *menuitem,
-					gpointer         user_data)
-{
-    if(!widgets_blocked)  prefs_window_create (-1);
-}
-
-void
+G_MODULE_EXPORT void
 on_edit_repository_options_activate          (GtkMenuItem     *menuitem,
 					      gpointer         user_data)
 {
@@ -830,7 +924,7 @@ on_edit_repository_options_activate          (GtkMenuItem     *menuitem,
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_load_ipods_mi           (GtkMenuItem     *menuitem,
 			    gpointer         user_data)
 {
@@ -838,7 +932,7 @@ on_load_ipods_mi           (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_load_ipods_clicked               (GtkButton       *button,
 				     gpointer         user_data)
 {
@@ -846,7 +940,7 @@ on_load_ipods_clicked               (GtkButton       *button,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_save_changes_mi           (GtkMenuItem     *menuitem,
 			      gpointer         user_data)
 {
@@ -855,7 +949,7 @@ on_save_changes_mi           (GtkMenuItem     *menuitem,
 
 
 
-void
+G_MODULE_EXPORT void
 on_save_changes_clicked               (GtkButton       *button,
 				     gpointer         user_data)
 {
@@ -863,7 +957,7 @@ on_save_changes_clicked               (GtkButton       *button,
 }
 
 
-
+G_MODULE_EXPORT 
 void on_edit_smart_playlist (GtkMenuItem *mi,
 			     gpointer data)
 {
@@ -928,13 +1022,14 @@ static void delete_selected_playlist (DeleteAction deleteaction)
     }
 }
 
-void on_delete_selected_tracks_from_database (GtkMenuItem *mi,
+G_MODULE_EXPORT void
+on_delete_selected_tracks_from_database (GtkMenuItem *mi,
 					      gpointer data)
 {
     delete_selected_tracks (DELETE_ACTION_DATABASE);
 }
 
-void
+G_MODULE_EXPORT void
 on_delete_selected_playlist_including_tracks_from_harddisk (GtkMenuItem *mi,
 							    gpointer data)
 {
@@ -942,7 +1037,8 @@ on_delete_selected_playlist_including_tracks_from_harddisk (GtkMenuItem *mi,
 }
 
 
-void on_delete_selected_entry_from_database (GtkMenuItem *mi,
+G_MODULE_EXPORT void
+on_delete_selected_entry_from_database (GtkMenuItem *mi,
 					     gpointer data)
 {
     delete_selected_entry (DELETE_ACTION_DATABASE, 
@@ -950,7 +1046,8 @@ void on_delete_selected_entry_from_database (GtkMenuItem *mi,
 }
 
 
-void on_delete_selected_entry_from_ipod (GtkMenuItem *mi,
+G_MODULE_EXPORT void
+on_delete_selected_entry_from_ipod (GtkMenuItem *mi,
 					 gpointer data)
 {
     delete_selected_entry (DELETE_ACTION_IPOD,
@@ -958,21 +1055,24 @@ void on_delete_selected_entry_from_ipod (GtkMenuItem *mi,
 }
 
 
-void on_delete_selected_tracks_from_playlist (GtkMenuItem *mi,
+G_MODULE_EXPORT void
+on_delete_selected_tracks_from_playlist (GtkMenuItem *mi,
 					      gpointer data)
 {
     delete_selected_tracks (DELETE_ACTION_PLAYLIST);
 }
 
 
-void on_delete_selected_tracks_from_harddisk (GtkMenuItem *mi,
+G_MODULE_EXPORT void
+on_delete_selected_tracks_from_harddisk (GtkMenuItem *mi,
 					      gpointer data)
 {
     delete_selected_tracks (DELETE_ACTION_LOCAL);
 }
 
 
-void on_delete_selected_entry_from_harddisk (GtkMenuItem *mi,
+G_MODULE_EXPORT void
+on_delete_selected_entry_from_harddisk (GtkMenuItem *mi,
 					     gpointer data)
 {
     delete_selected_entry (DELETE_ACTION_LOCAL,
@@ -980,21 +1080,23 @@ void on_delete_selected_entry_from_harddisk (GtkMenuItem *mi,
 }
 
 
-void on_delete_selected_tracks_from_ipod (GtkMenuItem *mi,
+G_MODULE_EXPORT void
+on_delete_selected_tracks_from_ipod (GtkMenuItem *mi,
 					  gpointer data)
 {
     delete_selected_tracks (DELETE_ACTION_IPOD);
 }
 
 
-void on_delete_selected_playlist (GtkMenuItem *mi,
+G_MODULE_EXPORT void
+on_delete_selected_playlist (GtkMenuItem *mi,
 				  gpointer data)
 {
     delete_selected_playlist (DELETE_ACTION_PLAYLIST);
 }
 
 
-void
+G_MODULE_EXPORT void
 on_delete_selected_playlist_including_tracks_from_database (GtkMenuItem *mi,
 							    gpointer data)
 {
@@ -1002,7 +1104,8 @@ on_delete_selected_playlist_including_tracks_from_database (GtkMenuItem *mi,
 }
 
 
-void on_delete_selected_entry_from_playlist (GtkMenuItem *mi,
+G_MODULE_EXPORT void
+on_delete_selected_entry_from_playlist (GtkMenuItem *mi,
 					     gpointer data)
 {
     delete_selected_entry (DELETE_ACTION_PLAYLIST,
@@ -1010,7 +1113,7 @@ void on_delete_selected_entry_from_playlist (GtkMenuItem *mi,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_delete_selected_playlist_including_tracks_from_ipod (GtkMenuItem *mi,
 							gpointer data)
 {
@@ -1018,7 +1121,7 @@ on_delete_selected_playlist_including_tracks_from_ipod (GtkMenuItem *mi,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_ipod_directories_menu               (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1039,7 +1142,7 @@ on_ipod_directories_menu               (GtkMenuItem     *menuitem,
 		GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_MESSAGE_WARNING,
 		GTK_BUTTONS_OK,
-		str);
+		"%s", str);
 	    gtk_dialog_run (GTK_DIALOG (dialog));
 	    gtk_widget_destroy (dialog);
 	    g_free (str);
@@ -1056,7 +1159,7 @@ on_ipod_directories_menu               (GtkMenuItem     *menuitem,
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_check_ipod_files_activate           (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1077,7 +1180,7 @@ on_check_ipod_files_activate           (GtkMenuItem     *menuitem,
 		GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_MESSAGE_WARNING,
 		GTK_BUTTONS_OK,
-		str);
+		"%s", str);
 	    gtk_dialog_run (GTK_DIALOG (dialog));
 	    gtk_widget_destroy (dialog);
 	    g_free (str);
@@ -1095,7 +1198,7 @@ on_check_ipod_files_activate           (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_update_playlist_activate (GtkMenuItem     *menuitem,
 			     gpointer         user_data)
 {
@@ -1103,7 +1206,7 @@ on_update_playlist_activate (GtkMenuItem     *menuitem,
 }
 
 /* update tracks in tab entry */
-void
+G_MODULE_EXPORT void
 on_update_tab_entry_activate        (GtkMenuItem     *menuitem,
 				     gpointer         user_data)
 {
@@ -1113,15 +1216,22 @@ on_update_tab_entry_activate        (GtkMenuItem     *menuitem,
     if (inst != -1) gp_do_selected_entry (update_tracks, inst);
 }
 
-void
+G_MODULE_EXPORT void
 on_update_tracks_activate            (GtkMenuItem     *menuitem,
 				     gpointer         user_data)
 {
     gp_do_selected_tracks (update_tracks);
 }
 
+G_MODULE_EXPORT void
+on_mserv_from_file_playlist_menu_activate
+                                        (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    gp_do_selected_playlist (mserv_from_file_tracks);
+}
 
-void
+G_MODULE_EXPORT void
 on_mserv_from_file_tracks_menu_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -1130,7 +1240,7 @@ on_mserv_from_file_tracks_menu_activate
 }
 
 
-void
+G_MODULE_EXPORT void
 on_mserv_from_file_entry_menu_activate (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
@@ -1141,7 +1251,7 @@ on_mserv_from_file_entry_menu_activate (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_sync_playlist_activate (GtkMenuItem     *menuitem,
 			     gpointer         user_data)
 {
@@ -1162,7 +1272,7 @@ on_sync_playlist_activate (GtkMenuItem     *menuitem,
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_save_track_order1_activate           (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1170,7 +1280,7 @@ on_save_track_order1_activate           (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_toolbar_menu_activate               (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1180,7 +1290,17 @@ on_toolbar_menu_activate               (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
+on_filterbar_menu_activate               (GtkMenuItem     *menuitem,
+					  gpointer         user_data)
+{
+    prefs_set_int("display_search_entry",
+	gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (menuitem)));
+    display_show_hide_searchbar ();
+}
+
+
+G_MODULE_EXPORT void
 on_more_sort_tabs_activate             (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1189,7 +1309,7 @@ on_more_sort_tabs_activate             (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_less_sort_tabs_activate             (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1197,7 +1317,7 @@ on_less_sort_tabs_activate             (GtkMenuItem     *menuitem,
     st_show_visible();
 }
 
-void
+G_MODULE_EXPORT void
 on_export_playlist_activate  (GtkMenuItem     *menuitem,
 			      gpointer         user_data)
 {
@@ -1214,7 +1334,7 @@ on_export_playlist_activate  (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_export_tab_entry_activate (GtkMenuItem     *menuitem,
 			      gpointer         user_data)
 {
@@ -1235,7 +1355,7 @@ on_export_tab_entry_activate (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_export_tracks_activate     (GtkMenuItem     *menuitem,
 			      gpointer         user_data)
 {
@@ -1253,7 +1373,7 @@ on_export_tracks_activate     (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_playlist_file_playlist_activate     (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
@@ -1270,7 +1390,7 @@ on_playlist_file_playlist_activate     (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_playlist_file_tab_entry_activate    (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
@@ -1291,7 +1411,7 @@ on_playlist_file_tab_entry_activate    (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_playlist_file_tracks_activate       (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
@@ -1308,7 +1428,7 @@ on_playlist_file_tracks_activate       (GtkMenuItem     *menuitem,
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_play_playlist_activate              (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1324,7 +1444,7 @@ on_play_playlist_activate              (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_play_tab_entry_activate             (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1345,7 +1465,7 @@ on_play_tab_entry_activate             (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_play_tracks_activate                 (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1363,7 +1483,7 @@ on_play_tracks_activate                 (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_enqueue_playlist_activate           (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1379,7 +1499,7 @@ on_enqueue_playlist_activate           (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_enqueue_tab_entry_activate          (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1400,7 +1520,7 @@ on_enqueue_tab_entry_activate          (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_enqueue_tracks_activate              (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1418,14 +1538,14 @@ on_enqueue_tracks_activate              (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_arrange_sort_tabs_activate          (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
     st_arrange_visible_sort_tabs ();
 }
 
-void
+G_MODULE_EXPORT void
 on_tooltips_menu_activate              (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1435,21 +1555,21 @@ on_tooltips_menu_activate              (GtkMenuItem     *menuitem,
     
 }
 
-void
+G_MODULE_EXPORT void
 on_pl_containing_displayed_tracks_activate (GtkMenuItem     *menuitem,
 					    gpointer         user_data)
 {
     generate_displayed_playlist ();
 }
 
-void
+G_MODULE_EXPORT void
 on_pl_containing_selected_tracks_activate (GtkMenuItem     *menuitem,
 					    gpointer         user_data)
 {
     generate_selected_playlist ();
 }
 
-void
+G_MODULE_EXPORT void
 on_pl_for_each_artist_activate         (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1465,7 +1585,7 @@ on_pl_for_each_artist_activate         (GtkMenuItem     *menuitem,
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_pl_for_each_album_activate         (GtkMenuItem     *menuitem,
 				       gpointer         user_data)
 {
@@ -1481,7 +1601,7 @@ on_pl_for_each_album_activate         (GtkMenuItem     *menuitem,
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_pl_for_each_genre_activate         (GtkMenuItem     *menuitem,
 				       gpointer         user_data)
 {
@@ -1497,7 +1617,7 @@ on_pl_for_each_genre_activate         (GtkMenuItem     *menuitem,
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_pl_for_each_composer_activate         (GtkMenuItem     *menuitem,
 					  gpointer         user_data)
 {
@@ -1514,7 +1634,7 @@ on_pl_for_each_composer_activate         (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_pl_for_each_year_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
@@ -1531,7 +1651,7 @@ on_pl_for_each_year_activate           (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_most_listened_tracks1_activate       (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1548,7 +1668,7 @@ on_most_listened_tracks1_activate       (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_all_tracks_never_listened_to1_activate
 					(GtkMenuItem     *menuitem,
 					gpointer         user_data)
@@ -1565,7 +1685,7 @@ on_all_tracks_never_listened_to1_activate
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_most_rated_tracks_playlist_s1_activate
 					(GtkMenuItem     *menuitem,
 					gpointer         user_data)
@@ -1583,7 +1703,7 @@ on_most_rated_tracks_playlist_s1_activate
 }
 
 
-void
+G_MODULE_EXPORT void
 on_most_recent_played_tracks_activate   (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1599,7 +1719,7 @@ on_most_recent_played_tracks_activate   (GtkMenuItem     *menuitem,
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_played_since_last_time1_activate    (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1615,14 +1735,14 @@ on_played_since_last_time1_activate    (GtkMenuItem     *menuitem,
     }
 }
 
-void
+G_MODULE_EXPORT void
 on_sorting_activate                    (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
     sort_window_create ();
 }
 
-void
+G_MODULE_EXPORT void
 on_normalize_selected_playlist_activate
 					(GtkMenuItem     *menuitem,
 					gpointer         user_data)
@@ -1635,7 +1755,7 @@ on_normalize_selected_playlist_activate
 }
 
 
-void
+G_MODULE_EXPORT void
 on_normalize_selected_tab_entry_activate
 					(GtkMenuItem     *menuitem,
 					gpointer         user_data)
@@ -1660,7 +1780,7 @@ on_normalize_selected_tab_entry_activate
 }
 
 
-void
+G_MODULE_EXPORT void
 on_normalize_selected_tracks_activate   (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1670,7 +1790,7 @@ on_normalize_selected_tracks_activate   (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_normalize_displayed_tracks_activate  (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1680,7 +1800,7 @@ on_normalize_displayed_tracks_activate  (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_normalize_all_tracks                (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1699,7 +1819,7 @@ on_normalize_all_tracks                (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_normalize_newly_added_tracks        (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1716,16 +1836,17 @@ on_normalize_newly_added_tracks        (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_info_window1_activate               (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (menuitem)))
-	 info_open_window ();
-    else info_close_window ();
+		open_info_dialog ();
+    else
+		close_info_dialog ();
 }
 
-void
+G_MODULE_EXPORT void
 on_conversion_log1_activate               (GtkMenuItem     *menuitem,
 					   gpointer         user_data)
 {
@@ -1741,7 +1862,7 @@ on_conversion_log1_activate               (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_sync_all_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
@@ -1762,7 +1883,7 @@ on_sync_all_activate                   (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_sync_calendar_activate              (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1778,7 +1899,7 @@ on_sync_calendar_activate              (GtkMenuItem     *menuitem,
 }
 
 
-void
+G_MODULE_EXPORT void
 on_sync_contacts_activate              (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
@@ -1793,8 +1914,7 @@ on_sync_contacts_activate              (GtkMenuItem     *menuitem,
     }
 }
 
-
-void
+G_MODULE_EXPORT void
 on_sync_notes_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
@@ -1808,8 +1928,7 @@ on_sync_notes_activate                 (GtkMenuItem     *menuitem,
 	message_sb_no_ipod_itdb_selected ();
     }
 }
-
-void
+G_MODULE_EXPORT void
 on_all_tracks_not_listed_in_any_playlist1_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -1826,8 +1945,7 @@ on_all_tracks_not_listed_in_any_playlist1_activate
     }
 }
 
-
-void
+G_MODULE_EXPORT void
 on_random_playlist_activate            (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
@@ -1843,15 +1961,13 @@ on_random_playlist_activate            (GtkMenuItem     *menuitem,
     }
 }
 
-
-void
+G_MODULE_EXPORT void
 on_randomize_current_playlist_activate (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
     randomize_current_playlist();
 }
-
-void
+G_MODULE_EXPORT void
 on_pl_for_each_rating_activate         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
