@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display_coverart.c 2051 2008-07-18 09:04:25Z phantom_sf $
+|  $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -630,7 +630,7 @@ static void draw (cairo_t *cairo_context)
  */
 void coverart_display_update (gboolean clear_track_list)
 {
-  gint i;
+  gint i, sort;
   GList *tracks;
   Track *track;
   Album_Item *album;
@@ -687,12 +687,12 @@ void coverart_display_update (gboolean clear_track_list)
         album->albumname = g_strdup (track->album);
         album->artist = g_strdup (track->artist);
         album->tracks = NULL;
-        album->tracks = g_list_append (album->tracks, track);
+        album->tracks = g_list_prepend (album->tracks, track);
 
         /* Insert the new Album Item into the hash */
         g_hash_table_insert (album_hash, album_key, album);
         /* Add the key to the list for sorting and other functions */
-        album_key_list = g_list_append (album_key_list, album_key);
+        album_key_list = g_list_prepend (album_key_list, album_key);
       }
       else
       {
@@ -700,7 +700,7 @@ void coverart_display_update (gboolean clear_track_list)
          * append the track to the end of the
          * track list */
         g_free (album_key);
-        album->tracks = g_list_append (album->tracks, track);
+        album->tracks = g_list_prepend (album->tracks, track);
       }
 
       tracks = tracks->next;
@@ -713,7 +713,16 @@ void coverart_display_update (gboolean clear_track_list)
   album_key_list = g_list_remove_all (album_key_list, NULL);
 
   /* Sort the tracks to the order set in the preference */
-  coverart_sort_images (prefs_get_int("st_sort"));
+  sort = prefs_get_int("st_sort");
+  if (sort != SORT_NONE)
+  {
+      coverart_sort_images (sort);
+  }
+  else
+  {
+      /* restore original order) */
+      album_key_list = g_list_reverse (album_key_list);
+  }
 
   /* Add 4 null tracks to the end of the track list for padding */
   for (i = 0; i < IMG_MAIN; ++i)
@@ -2108,6 +2117,12 @@ static void dnd_coverart_drag_data_received(GtkWidget *widget, GdkDragContext *d
 
   /* Find the display cover item in the cover display */
   cover = g_ptr_array_index(cdwidget->cdcovers, IMG_MAIN);
+  if (!cover) {
+      /* looks like there are no covers yet something got dragged into it */
+      gtk_drag_finish (dc, FALSE, FALSE, time);
+      return;
+  }
+
   tracks = cover->album->tracks;
 
   switch (info)
