@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display_itdb.c 2148 2008-11-08 08:02:15Z jcsjcs $
+|  $Id$
 */
 
 #ifdef HAVE_CONFIG_H
@@ -860,7 +860,7 @@ void init_data (GtkWidget *window)
     {
 	/* databases have not been set up previously -- take care of
 	   this */
-#ifndef HAVE_GNOME_VFS
+#ifndef HAVE_GIO
 	gchar *mountpoint;
 #endif
 	gchar *filename;
@@ -880,7 +880,7 @@ void init_data (GtkWidget *window)
 	prefs_set_string ("itdb_1_filename", filename);
 	g_free (filename);
 
-#ifndef HAVE_GNOME_VFS
+#ifndef HAVE_GIO
 	/* iPod database -- only set up if autodetection is not active */
 	mountpoint = prefs_get_string ("initial_mountpoint");
 	filename = g_build_filename (cfgdir, "iTunesDB", NULL);
