@@ -23,7 +23,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display_playlists.c 2084 2008-08-03 02:59:01Z jcsjcs $
+|  $Id$
 */
 
 #ifdef HAVE_CONFIG_H
@@ -105,23 +105,23 @@ static void pm_drag_begin (GtkWidget *widget,
 }
 
 
+static void pm_drag_data_delete_remove_playlist(
+GtkTreeModel *tm, GtkTreePath *tp,
+GtkTreeIter *iter, gpointer data)
+{
+    Playlist *pl;
+    g_return_if_fail (tm);
+    g_return_if_fail (iter);
+    gtk_tree_model_get (tm, iter, PM_COLUMN_PLAYLIST, &pl, -1);
+    g_return_if_fail (pl);
+    gp_playlist_remove (pl);
+}
+
 /* remove dragged playlist after successful MOVE */
 static void pm_drag_data_delete (GtkWidget *widget,
 			   GdkDragContext *drag_context,
 			   gpointer user_data)
 {
-    void pm_drag_data_delete_remove_playlist(
-	GtkTreeModel *tm, GtkTreePath *tp,
-	GtkTreeIter *iter, gpointer data)
-	{
-	    Playlist *pl;
-	    g_return_if_fail (tm);
-	    g_return_if_fail (iter);
-	    gtk_tree_model_get (tm, iter, PM_COLUMN_PLAYLIST, &pl, -1);
-	    g_return_if_fail (pl);
-	    gp_playlist_remove (pl);
-	}
-
     g_return_if_fail (widget);
     g_return_if_fail (drag_context);
 
@@ -1433,11 +1433,13 @@ void pm_unselect_playlist (Playlist *playlist)
 }
 
 
-static void pm_selection_changed_cb (GtkTreeSelection *selection,
-				     gpointer user_data2)
+static gboolean
+pm_selection_changed_cb (gpointer data)
 {
 	GtkTreeModel *model;
 	GtkTreeIter  iter;
+	GtkTreeView *tree_view = GTK_TREE_VIEW (data);
+	GtkTreeSelection *selection = gtk_tree_view_get_selection (tree_view);
 
 #if DEBUG_TIMING
 	GTimeVal time;
@@ -1479,8 +1481,8 @@ static void pm_selection_changed_cb (GtkTreeSelection *selection,
 	    switch (type)
 	    {
 	    case PM_COLUMN_PLAYLIST:
-		g_return_if_fail (new_playlist);
-		g_return_if_fail (itdb);
+		g_return_val_if_fail (new_playlist, FALSE);
+		g_return_val_if_fail (itdb, FALSE);
 
 		gphoto_change_to_photo_window (FALSE);
 
@@ -1525,8 +1527,8 @@ static void pm_selection_changed_cb (GtkTreeSelection *selection,
 		gtkpod_tracks_statusbar_update();
 		break;
 	    case PM_COLUMN_PHOTOS:
-		g_return_if_fail (photodb);
-		g_return_if_fail (itdb);
+		g_return_val_if_fail (photodb, FALSE);
+		g_return_val_if_fail (itdb, FALSE);
 		gphoto_display_photo_window (itdb);
 		break;
 	    case PM_COLUMN_ITDB:
@@ -1550,6 +1552,8 @@ static void pm_selection_changed_cb (GtkTreeSelection *selection,
 #endif 
 	/* make only suitable delete menu items available */
 	display_adjust_menus ();
+
+	return FALSE;
 }
 
 /* Callback function called when the selection
@@ -1558,7 +1562,10 @@ static void pm_selection_changed (GtkTreeSelection *selection,
 				  gpointer user_data)
 {
     if (!pm_selection_blocked)
-	pm_selection_changed_cb (selection, user_data);
+    {
+	g_idle_add (pm_selection_changed_cb,
+		    gtk_tree_selection_get_tree_view (selection));
+    }
 }
 
 
