@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: file.c 2185 2008-12-31 22:30:36Z jcsjcs $
+|  $Id$
 */
 
 #ifdef HAVE_CONFIG_H
@@ -144,7 +144,10 @@ FileType determine_file_type (const gchar *path)
 
 	else if (g_strcasecmp (suf, ".m3u") == 0) type = FILE_TYPE_M3U;
 	else if (g_strcasecmp (suf, ".pls") == 0) type = FILE_TYPE_PLS;
-        else if (g_strcasecmp (suf, ".ogg") == 0) type = FILE_TYPE_OGG;
+	else if (g_strcasecmp (suf, ".oga") == 0) type = FILE_TYPE_OGG;
+	else if (g_strcasecmp (suf, ".ogg") == 0) type = FILE_TYPE_OGG;
+	else if (g_strcasecmp (suf, ".ogv") == 0) type = FILE_TYPE_OGG;
+	else if (g_strcasecmp (suf, ".ogx") == 0) type = FILE_TYPE_OGG;
         else if (g_strcasecmp (suf, ".flac") == 0) type = FILE_TYPE_FLAC;
 
 	else
@@ -1306,13 +1309,21 @@ static Track *get_track_info_from_file (gchar *name, Track *orig_track)
     case FILE_TYPE_MP3:
 	nti = mp3_get_file_info (name);
 	/* Set mediatype to audio */
-	if (nti) nti->mediatype = ITDB_MEDIATYPE_AUDIO;
+	if (nti)
+	{
+	    nti->mediatype = ITDB_MEDIATYPE_AUDIO;
+	    if (nti->genre)
+	    {
+		if (g_strcasecmp (nti->genre, "audiobook") == 0) nti->mediatype = ITDB_MEDIATYPE_AUDIOBOOK;
+		else if (g_strcasecmp (nti->genre, "podcast") == 0) nti->mediatype = ITDB_MEDIATYPE_PODCAST;
+	    }
+	}
 	break;
     case FILE_TYPE_M4A:
     case FILE_TYPE_M4P:
 	nti = mp4_get_file_info (name);
 	/* Set mediatype to audio */
-	if (nti)
+	if (nti && !nti->mediatype)
 	{
 	    nti->mediatype = ITDB_MEDIATYPE_AUDIO;
 	}
@@ -1358,7 +1369,8 @@ static Track *get_track_info_from_file (gchar *name, Track *orig_track)
 	/* Set mediatype to video */
 	if (nti)
 	{
-	    nti->mediatype = ITDB_MEDIATYPE_MOVIE;
+	    if (!nti->mediatype)
+            nti->mediatype = ITDB_MEDIATYPE_MOVIE;
 	    nti->movie_flag = 0x01;
 	}	
 	break;
@@ -1384,6 +1396,21 @@ static Track *get_track_info_from_file (gchar *name, Track *orig_track)
 	break;
     }
 
+    if (nti)
+    {
+	switch (nti->mediatype)
+	{
+	    case ITDB_MEDIATYPE_AUDIOBOOK:
+	    case ITDB_MEDIATYPE_PODCAST:
+	    case ITDB_MEDIATYPE_PODCAST|ITDB_MEDIATYPE_MOVIE: /* Video podcast */
+		/* For audiobooks and podcasts, default to remember playback position
+		 * and skip when shuffling. */
+		nti->skip_when_shuffling = 1;
+		nti->remember_playback_position = 1;
+		break;
+	}
+    }
+
     if (nti)
     {
 	ExtraTrackData *enti=nti->userdata;
@@ -2604,7 +2631,7 @@ gboolean read_lyrics_from_file (Track *track, gchar **lyrics)
         case FILE_TYPE_MP4:
             result = TRUE;
             *lyrics=g_strdup(
-                "File format unsupported now.");
+                _("Error: File format unsupported now."));
             break;
         case FILE_TYPE_MOV:
         case FILE_TYPE_MPG:
@@ -2614,7 +2641,7 @@ gboolean read_lyrics_from_file (Track *track, gchar **lyrics)
         case FILE_TYPE_UNKNOWN:
             result = TRUE;
             *lyrics=g_strdup(
-                "Lyrics not supported for this file format.");
+                _("Error: Lyrics not supported for this file format."));
             break;
         case FILE_TYPE_M3U:
         case FILE_TYPE_PLS:
@@ -2627,8 +2654,8 @@ gboolean read_lyrics_from_file (Track *track, gchar **lyrics)
     else
     {
         buf = get_track_info (track, FALSE);
-        gtkpod_warning (
-            _("Lyrics not found, file not available (%s).\n\n"),
+        *lyrics=g_strdup_printf(
+            _("Error: Lyrics not found, file not available (%s).\n\n"),
             buf);
         g_free (buf);
     }
@@ -2655,6 +2682,12 @@ gboolean write_lyrics_to_file (Track *track)
     g_return_val_if_fail (track, FALSE);
     etr = track->userdata;
     g_return_val_if_fail (etr,FALSE);
+
+    if (g_str_has_prefix(etr->lyrics, _("Error:"))) {
+        /* Not writing lyrics as there are only errors */
+        return FALSE;
+    }
+
     itdb = track->itdb;
     g_return_val_if_fail (itdb, FALSE);
     path = get_file_name_from_source (track, SOURCE_IPOD);
