@@ -23,7 +23,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: info.c 1894 2008-01-01 19:26:37Z Sikon $
+|  $Id$
 */
 
 /* This file provides functions for the info window as well as for the
@@ -710,16 +710,10 @@ static void th_space_update (void)
     gchar *mp=NULL, *line=NULL;
     gchar **tokens = NULL;
 
-    /* don't read info when in offline mode */
-    if (!prefs_get_offline ())
-    {
 	g_mutex_lock (space_mutex);
 	mp = g_strdup (space_mp);
 	g_mutex_unlock (space_mutex);
 
-	line = get_drive_stats_from_df (mp);
-    }
-
     g_mutex_lock (space_mutex);
 
     if (line) tokens = g_strsplit(line, " ", 5);
