@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: misc.c 1822 2007-12-12 16:31:26Z dforsi $
+|  $Id$
 */
 
 #ifdef HAVE_CONFIG_H
@@ -43,6 +43,7 @@
 #include "clientserver.h"
 #include "file_convert.h"
 #include "misc.h"
+#include "mp4file.h"
 #include "prefs.h"
 #include "misc_track.h"
 #include "display_photo.h"
@@ -55,136 +56,18 @@
 const gchar *SCRIPTDIR = PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "scripts" G_DIR_SEPARATOR_S;
 
 
-/*------------------------------------------------------------------*\
- *                                                                  *
- *             About Window                                         *
- *                                                                  *
-\*------------------------------------------------------------------*/
-
-/* ATTENTION: directly used as callback in gtkpod.glade -- if you
-   change the arguments of this function make sure you define a
-   separate callback for gtkpod.glade */
-void open_about_window ()
-{
-	const gchar *authors[] = {
-		_("© 2002 - 2007\n"
-		    "Jorg Schuler (jcsjcs at users dot sourceforge dot net)\n"
-		    "Corey Donohoe (atmos at atmos dot org)\n"
-		    ""),
-		_("Patches were supplied by the following people (list may be incomplete -- please contact me)\n"),
-		_("Ramesh Dharan: Multi-Edit (edit tags of several tracks in one run)"),
-		_("Hiroshi Kawashima: Japanese charset autodetection feature"),
-		_("Adrian Ulrich: porting of playlist code from mktunes.pl to itunesdb.c"),
-		_("Walter Bell: correct handling of DND URIs with escaped characters and/or cr/newlines at the end"),
-		_("Sam Clegg: user defined filenames when exporting tracks from the iPod"),
-		_("Chris Cutler: automatic creation of various playlist types"),
-		_("Graeme Wilford: reading and writing of the 'Composer' ID3 tags, progress dialogue during sync"),
-		_("Edward Matteucci: debugging, special playlist creation, most of the volume normalizing code"),
-		_("Jens Lautenbach: some optical improvements"),
-		_("Alex Tribble: iPod eject patch"),
-		_("Yaroslav Halchenko: Orphaned and dangling tracks handling"),
-		_("Andrew Huntwork: Filename case sensitivity fix and various other bugfixes"),
-		_("Ero Carrera: Filename validation and quick sync when copying tracks from the iPod"),
-		_("Jens Taprogge: Support for LAME's replay gain tag to normalize volume"),
-		_("Armando Atienza: Support with external playcounts"),
-		_("D.L. Sharp: Support for m4b files (bookmarkable AAC files)"),
-		_("Jim Hall: Decent INSTALL file"),
-		_("Juergen Helmers, Markus Gaugusch: Conversion scripts to sync calendar/contacts to the iPod"),    /* J"urgen! */
-		_("Flavio Stanchina: bugfixes"),
-		_("Chris Micacchi: when sorting ignore 'the' and similar at the beginning of the title"),
-		_("Steve Jay: use statvfs() instead of df (better portability, faster)"),
-		"",
-		_("Christoph Kunz: address compatibility issues when writing id3v2.4 type mp3 tags"),
-		"",
-		_("James Liggett:\n"
-		    "replacement of old GTK file selection dialogs with new GTK filechooser dialogs\n"
-		    "refactored user preferences system."),
-		"",
-		_("Daniel Kercher: sync scripts for abook and webcalendar"),
-		"",
-		_("Clinton Gormley: sync scripts for thunderbird"),
-		"",
-		_("Sebastien Beridot: sync script for ldif addressbook format"),
-		"",
-		_("Sebastian Scherer: sync script for kNotes"),
-		"",
-		_("Nick Piper: sync script for Palm, type-ahead search"),
-		"",
-		_("Uwe Hermann: help with support for iPod Video"),
-		"",
-		_("Iain Benson: support for compilation tag in mp3 files and separate display of compilations in the sort tab."),
-		_("Nicolas Chariot: icons of buttons\n"
-		    "\n"),
-		_("This program borrows code from the following projects:"),
-		_("gnutools: (mktunes.pl, ported to C) reading and writing of iTunesDB  (http://www.gnu.org/software/gnupod/)"),
-		_("iPod.cpp, iPod.h by Samuel Wood (sam dot wood at gmail dot com): some code for smart playlists is based on his C++-classes."),
-		_("mp3info: mp3 playlength detection (http://ibiblio.org/mp3info/)"),
-		_("xmms: dirbrowser, mp3 playlength detection (http://www.xmms.org)"),
-		"",
-		_("The GUI was created with the help of glade-2 (http://glade.gnome.org/)."),
-		NULL };
-
-	gchar  *translators[] = {
-		_("French: David Le Brun (david at dyn-ns dot net)"),
-		_("French: Éric Lassauge (rpmfarm at free dot fr)"),
-		_("German: Jorg Schuler (jcsjcs at users dot sourceforge dot net)"),
-		_("German: Kai-Ove"),
-		_("Hebrew: Assaf Gillat (gillata at gmail dot com)"),
-		_("Italian: Edward Matteucci (edward_matteucc at users dot sourceforge dot net)"),
-		_("Italian: Daniele Forsi (dforsi at gmail dot com)"),
-		_("Japanese: Ayako Sano"),
-		_("Japanese: Kentaro Fukuchi (fukuchi at users dot sourceforge dot net)"),
-		_("Romanian: Alex Eftimie (alexeftimie at gmail dot com)"),
-		_("Spanish: Alejandro Lamas Daviña (alejandro.lamas at ific dot uv dot es)"),
-		_("Swedish: Stefan Asserhall (stefan.asserhall at comhem dot se)"),
-		NULL
-	};
-
-	gchar *license = _(
-		"This program is free software; you can redistribute it and/or\n"
-		"modify it under the terms of the GNU General Public License as\n"
-		"published by the Free Software Foundation; either version 2 of the\n"
-		"License, or (at your option) any later version.\n"
-		"\n"
-		"This program is distributed in the hope that it will be useful, but\n"
-		"WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-		"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See\n"
-		"the GNU General Public License for more details.\n"
-		"\n"
-		"You should have received a copy of the GNU General Public\n"
-		"License along with this program; if not, write to the Free Software\n"
-		"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA\n02111-1307, USA."
-	);
-
-	gchar *copyright = _("© 2002-2007\nJorg Schuler <jcsjcs@users.sourceforge.net>\nCorey Donohoe <atmos@atmos.org>");
-	gchar *translator_credits = g_strjoinv("\n", translators);
-	GdkPixbuf *icon = gdk_pixbuf_new_from_file(PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "data" G_DIR_SEPARATOR_S "gtkpod-logo.png", NULL);
-
-	gtk_show_about_dialog(GTK_WINDOW(gtkpod_window),
-		"name", "gtkpod",
-		"version", VERSION,
-		"logo", icon,
-		"comments", _("Cross-platform multilingual interface to Apple's iPod™"),
-		"copyright", copyright,
-		"website", "http://gtkpod.org",
-		"license", license,
-		"authors", authors,
-		"translator_credits", translator_credits,
-		NULL);
-
-	g_free(translator_credits);
-
-	if(icon)
-		g_object_unref(icon);
-}
-
-
 /*------------------------------------------------------------------*\
  *                                                                  *
  *             Miscellaneous                                        *
  *                                                                  *
 \*------------------------------------------------------------------*/
 
+gchar *utf8_strcasestr(const gchar *haystack, const gchar *needle) {
+    g_return_val_if_fail (haystack != NULL, NULL);
+    g_return_val_if_fail (needle != NULL, NULL);
+
+    return g_strrstr(haystack, needle);
+}
 
 /* Calculate the time in ms passed since @old_time. @old_time is
    updated with the current time if @update is TRUE*/
@@ -268,19 +151,6 @@ parse_artwork_from_string(gchar **s, Artwork **artwork)
     return FALSE;
 }
 
-/* Duplicate a GList (shallow copy) */
-GList *glist_duplicate (GList *list)
-{
-    auto void gl_dup_fe (gpointer data, GList **dup);
-    void gl_dup_fe (gpointer data, GList **dup)
-	{
-	    *dup = g_list_append (*dup, data);
-	}
-    GList *dup = NULL;
-    g_list_foreach (list, (GFunc)gl_dup_fe, &dup);
-    return dup;
-}
-
 
 /***************************************************************************
  * gtkpod.in,out calls
@@ -419,10 +289,15 @@ gchar **build_argv_from_strings (const gchar *first_arg, ...)
  * depending on prefs settings */
 gint compare_string (const gchar *str1, const gchar *str2)
 {
-    if (prefs_get_int("case_sensitive"))
-	return strcmp (str1, str2);
-    else
-	return compare_string_case_insensitive (str1, str2);
+    gint result;
+    gchar *sortkey1 = make_sortkey (str1);
+    gchar *sortkey2 = make_sortkey (str2);
+
+    result = strcmp (sortkey1, sortkey2);
+
+    g_free (sortkey1);
+    g_free (sortkey2);
+    return result;
 }
 
 struct csfk
@@ -434,6 +309,30 @@ struct csfk
 static GList *csfk_list = NULL;
 
 
+/* Returns the sortkey for an entry name.
+ *
+ * The sort key can be compared with other sort keys using strcmp and
+ * it will give the expected result, according to the user
+ * settings. Must be regenerated if the user settings change.
+ *
+ * The caller is responsible of freeing the returned key with g_free.
+ */
+gchar *
+make_sortkey (const gchar *name)
+{
+    if (prefs_get_int("case_sensitive"))
+    {
+	return g_utf8_collate_key (name, -1);
+    }
+    else
+    {
+	gchar *casefolded = g_utf8_casefold (name, -1);
+	gchar *key = g_utf8_collate_key (casefolded, -1);
+	g_free (casefolded);
+	return key;
+    }
+}
+
 /* needs to be called everytime the sort_ign_strings in the prefs were
    changed */
 void compare_string_fuzzy_generate_keys (void)
@@ -470,29 +369,20 @@ void compare_string_fuzzy_generate_keys (void)
 	csfk->key = g_utf8_collate_key (tempStr, -1 );
 	g_free (tempStr);
 
-	csfk_list = g_list_append (csfk_list, csfk);
+	csfk_list = g_list_prepend (csfk_list, csfk);
     }
     prefs_free_list(sort_ign_strings);
 }
 
-
-/* compare @str1 and @str2 case-sensitively or case-insensitively
- * depending on prefs settings, and ignoring certain initial articles 
- * ("the", "le"/"la", etc) */
-gint compare_string_fuzzy (const gchar *str1, const gchar *str2)
+/* Returns a pointer inside the name, possibly skiping a prefix from
+ * the list generated by compare_string_fuzzy_generate_keys.
+ */
+const gchar *
+fuzzy_skip_prefix (const gchar *name)
 {
-    gchar *tempStr;
-    gint   result;
-    
-    gchar *cleanStr1 = g_utf8_casefold (str1, -1);
-    gchar *cleanStr2 = g_utf8_casefold (str2, -1);
-
-    const gchar *pstr1 = str1;
-    const gchar *pstr2 = str2;
-    gchar *pcleanStr1 = cleanStr1;
-    gchar *pcleanStr2 = cleanStr2;
-    
-    GList *gl;
+    const gchar *result = name;
+    const GList *gl;
+    gchar *cleanStr;
 
     /* If the article collations keys have not been generated, 
      * do that first
@@ -500,57 +390,42 @@ gint compare_string_fuzzy (const gchar *str1, const gchar *str2)
     if (!csfk_list)
 	compare_string_fuzzy_generate_keys ();
 
-    if (!csfk_list)
-	return compare_string (str1, str2);
+    cleanStr = g_utf8_casefold (name, -1);
 
-    /* Check the beginnings of both strings for any of the 
-     * articles we should ignore
-     */
-    for (gl=csfk_list; gl; gl=gl->next)
+    for (gl=csfk_list; gl; gl=g_list_next(gl))
     {
 	struct csfk *csfk = gl->data;
+	gchar *tempStr;
+
 	g_return_val_if_fail (csfk, 0);
-    	tempStr = g_utf8_collate_key (cleanStr1, csfk->length);
+
+    	tempStr = g_utf8_collate_key (cleanStr, csfk->length);
 	if (strcmp (tempStr, csfk->key) == 0)
 	{
 	    /* Found article, bump pointers ahead appropriate distance
 	     */
-	    pstr1 += csfk->length;
-	    pcleanStr1 = g_utf8_offset_to_pointer (cleanStr1, csfk->length);
-	    g_free (tempStr);
-	    break;
-	}
-	g_free (tempStr);
-    }
-    for (gl=csfk_list; gl; gl=gl->next)
-    {
-	struct csfk *csfk = gl->data;
-	g_return_val_if_fail (csfk, 0);
-    	tempStr = g_utf8_collate_key (cleanStr2, csfk->length);
-	if (strcmp (tempStr, csfk->key) == 0)
-	{
-	    /* Found article, bump pointers ahead apropriate distance
-	     */
-	    pstr2 += csfk->length;
-	    pcleanStr2 = g_utf8_offset_to_pointer (cleanStr2, csfk->length);
+	    result += csfk->length;
 	    g_free (tempStr);
 	    break;
 	}
 	g_free (tempStr);
     }
 
-    if (prefs_get_int("case_sensitive"))
-	result = strcmp(pstr1, pstr2);
-    else
-    	result = g_utf8_collate(pcleanStr1, pcleanStr2);
+    g_free (cleanStr);
 
-    g_free (cleanStr1);
-    g_free (cleanStr2);
     return result;
 }
 
 /* compare @str1 and @str2 case-sensitively or case-insensitively
- * depending on prefs settings */
+ * depending on prefs settings, and ignoring certain initial articles 
+ * ("the", "le"/"la", etc) */
+gint compare_string_fuzzy (const gchar *str1, const gchar *str2)
+{
+    return compare_string (fuzzy_skip_prefix (str1),
+			   fuzzy_skip_prefix (str2));
+}
+
+/* compare @str1 and @str2 case-insensitively */
 gint compare_string_case_insensitive (const gchar *str1, const gchar *str2)
 {
     gchar *string1 = g_utf8_casefold (str1, -1);
@@ -1347,6 +1222,28 @@ gint64 get_size_of_directory (const gchar *dir)
 
 
 
+/**
+ * Wrapper for glade_xml_new() for cygwin compatibility issues
+ *
+ **/
+GladeXML *gtkpod_xml_new (const gchar *xml_file, const gchar *name)
+{
+    GladeXML *xml;
+	
+#ifdef ENABLE_NLS
+	xml = glade_xml_new (xml_file, name, GETTEXT_PACKAGE);
+#else
+	xml = glade_xml_new (xml_file, name, NULL);
+#endif
+
+    if (!xml)
+		fprintf (stderr, "*** Programming error: Cannot create glade XML: '%s'\n",
+				 name);
+
+    return xml;
+}
+
+
 /**
  * Wrapper for gtkpod_xml_get_widget() giving out a warning if widget
  * could not be found.
@@ -1354,16 +1251,15 @@ gint64 get_size_of_directory (const gchar *dir)
  **/
 GtkWidget *gtkpod_xml_get_widget (GladeXML *xml, const gchar *name)
 {
-    GtkWidget *w=glade_xml_get_widget (xml, name);
+    GtkWidget *w = glade_xml_get_widget (xml, name);
 
     if (!w)
-	fprintf (stderr, "*** Programming error: Widget not found: '%s'\n",
-		 name);
+		fprintf (stderr, "*** Programming error: Widget not found: '%s'\n",
+				 name);
 
     return w;
 }
 
-
 /* ------------------------------------------------------------
  *
  *        Helper functions for pref keys
@@ -1739,12 +1635,14 @@ static void load_ipod_index_prefs (gint index, const gchar *mountpoint)
 	GError *error = NULL;
 	gchar *path = g_build_filename (dir, "gtkpod.prefs", NULL);
 	temp_prefs = temp_prefs_load (path, &error);
+	g_free (path);
 	if (temp_prefs)
 	{
 	    gchar *subkey;
 	    subkey = get_itdb_prefs_key (index, "");
 	    /* rename 'itdb_*' to 'itdb_<index>_*' */
 	    temp_prefs_rename_subkey (temp_prefs, "itdb_", subkey);
+	    g_free (subkey);
 	    /* merge with real prefs */
 	    temp_prefs_apply (temp_prefs);
 	    /* destroy temp prefs */
@@ -1810,31 +1708,51 @@ void gtkpod_init (int argc, char *argv[])
     {
 	static const gchar *SEPsrcSEPgtkpod = G_DIR_SEPARATOR_S "src" G_DIR_SEPARATOR_S "gtkpod";
 
-	if (!g_path_is_absolute (progname))
-	{
-	    gchar *cur_dir = g_get_current_dir ();
-	    gchar *prog_absolute;
+    if (!g_path_is_absolute (progname))
+    {
+        gchar *cur_dir = g_get_current_dir ();
+        gchar *prog_absolute;
 
-	    if (g_str_has_prefix (progname, "." G_DIR_SEPARATOR_S))
-		prog_absolute = g_build_filename (cur_dir,progname+2,NULL);
-	    else
-		prog_absolute = g_build_filename (cur_dir,progname,NULL);
-	    g_free (progname);
-	    g_free (cur_dir);
-	    progname = prog_absolute;
-	}
+        if (g_str_has_prefix (progname, "." G_DIR_SEPARATOR_S))
+            prog_absolute = g_build_filename (cur_dir,progname+2,NULL);
+        else
+            prog_absolute = g_build_filename (cur_dir,progname,NULL);
+
+        g_free (progname);
+        g_free (cur_dir);
+        progname = prog_absolute;
+    }
+
+    if (g_str_has_suffix (progname, SEPsrcSEPgtkpod))
+    {
+        gchar *suffix = g_strrstr (progname, SEPsrcSEPgtkpod);
+
+        if (suffix)
+        {
+            *suffix = 0;
+            xml_file = g_build_filename (progname, "data", "gtkpod.glade", NULL);
+        }
+    }
+
+    if (!xml_file)
+    {
+        gchar *prog_path = g_path_get_dirname (progname);
+        gchar *cmake_file = g_build_filename (prog_path, "CMakeCache.txt", NULL);
+
+        if (g_file_test (cmake_file, G_FILE_TEST_EXISTS))
+        {
+            gchar *source_root = g_path_get_dirname (prog_path);
+            xml_file = g_build_filename(source_root, "data", "gtkpod.glade", NULL);
+            g_free (source_root);
+        }
+
+        g_free (cmake_file);
+        g_free (prog_path);
+    }
 
-	if (g_str_has_suffix (progname, SEPsrcSEPgtkpod))
-	{
-	    gchar *suffix = g_strrstr (progname, SEPsrcSEPgtkpod);
-	    if (suffix)
-	    {
-		*suffix = 0;
-		xml_file = g_build_filename (progname, "data", "gtkpod.glade", NULL);
-	    }
-	}
 	g_free (progname);
-	if (xml_file && !g_file_test (xml_file, G_FILE_TEST_EXISTS))
+
+    if (xml_file && !g_file_test (xml_file, G_FILE_TEST_EXISTS))
 	{
 	    g_free (xml_file);
 	    xml_file = NULL;
@@ -1847,10 +1765,13 @@ void gtkpod_init (int argc, char *argv[])
 	printf ("Using local gtkpod.glade file since program was started from source directory:\n%s\n", xml_file);
     }
 
+    /* Attempt to load libmp4v2 */
+    mp4_init();
+
     /* Initialisation of libxml */
     LIBXML_TEST_VERSION;
 
-    main_window_xml = glade_xml_new (xml_file, "gtkpod", NULL);
+    main_window_xml = gtkpod_xml_new (xml_file, "gtkpod");
 
     glade_xml_signal_autoconnect (main_window_xml);
   
@@ -1920,6 +1841,8 @@ void gtkpod_shutdown ()
 
     xmlCleanupParser();
     xmlMemoryDump();
+
+    mp4_close();
 	
     call_script ("gtkpod.out", NULL);
     gtk_main_quit ();
