@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: misc_conversion.c 1655 2007-07-27 02:22:31Z tiffman $
+|  $Id$
 */
 
 #ifdef HAVE_CONFIG_H
@@ -111,6 +111,7 @@ static const gchar *t_strings[] = {
     N_("Sort Composer"),
     N_("Sort TV Show"),
     N_("Gapless Track Flag"),
+    N_("Lyrics"),
     NULL };
 
 /* Tooltips for prefs window */
@@ -171,6 +172,7 @@ static const gchar *t_tooltips[] = {
     N_("Used for sorting on the iPod"),
     N_("Used for sorting on the iPod"),
     N_("Used for sorting on the iPod"),
+    NULL,
     NULL
  };
 
@@ -230,6 +232,7 @@ T_item TM_to_T (TM_item tm)
     case TM_COLUMN_SORT_ALBUMARTIST: return T_SORT_ALBUMARTIST;
     case TM_COLUMN_SORT_COMPOSER: return T_SORT_COMPOSER;
     case TM_COLUMN_SORT_TVSHOW:   return T_SORT_TVSHOW;
+    case TM_COLUMN_LYRICS:        return T_LYRICS;
     case TM_NUM_COLUMNS:          g_return_val_if_reached (-1);
     }
     return -1;
@@ -296,10 +299,9 @@ T_item ST_to_T (ST_CAT_item st)
     case ST_CAT_COMPOSER:    return T_COMPOSER;
     case ST_CAT_TITLE:       return T_TITLE;
     case ST_CAT_YEAR:        return T_YEAR;
-    case ST_CAT_SPECIAL:
-    case ST_CAT_NUM:         g_return_val_if_reached (-1);
+    case ST_CAT_SPECIAL:     g_return_val_if_reached (-1);
+    default:                 g_return_val_if_reached (-1);
     }
-    return -1;
 }
 
 
