@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: misc_playlist.c 1970 2008-05-11 06:07:12Z jcsjcs $
+|  $Id$
 */
 
 #ifdef HAVE_CONFIG_H
@@ -970,12 +970,7 @@ check_db_danglingok1 (gpointer user_data1, gpointer user_data2)
 
 
 
-/* checks iTunesDB for presence of dangling links and checks IPODs
- * Music directory on subject of orphaned files */
-void check_db (iTunesDB *itdb)
-{
-
-    void glist_list_tracks (GList * tlist, GString * str)
+static void glist_list_tracks (GList * tlist, GString * str)
 	{
 	    if (str==NULL)
 	    {
@@ -998,6 +993,12 @@ void check_db (iTunesDB *itdb)
 	    }
 	} /* end of glist_list_tracks */
 
+/* checks iTunesDB for presence of dangling links and checks IPODs
+ * Music directory on subject of orphaned files */
+void check_db (iTunesDB *itdb)
+{
+
+
     GTree *files_known = NULL;
     GDir  *dir_des = NULL;
 
