@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: mp4file.h,v 1.9 2006/06/11 16:04:51 jcsjcs Exp $
+|  $Id$
 */
 
 #ifndef MP4FILEH_INCLUDED
@@ -32,6 +32,9 @@
 
 #include "itdb.h"
 
+void mp4_init();
+void mp4_close();
+
 gboolean mp4_write_file_info (gchar *filename, Track *track);
 Track *mp4_get_file_info (gchar *name);
 gboolean mp4_read_soundcheck (gchar *filename, Track *track);
