@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: prefs.c 2216 2009-01-17 05:47:46Z jcsjcs $
+|  $Id$
 */
 
 /* -------------------------------------------------------------------
@@ -277,7 +277,6 @@ static void set_default_preferences()
     prefs_set_int("size_file_dialog_details.y", 140);
 
     prefs_set_int("readtags", TRUE);
-    prefs_set_int("write_extended_info", TRUE);
     prefs_set_int("parsetags", FALSE);
     prefs_set_int("parsetags_overwrite", FALSE);
     prefs_set_string("parsetags_template", "%a - %A/%T %t.mp3;%t.wav");
@@ -321,9 +320,13 @@ static void set_default_preferences()
     prefs_set_int("pm_sort", SORT_NONE);
     prefs_set_int("tm_sortcol", TM_COLUMN_TITLE);
     prefs_set_int("tm_sort", SORT_NONE);
-	
-	/* New conversion preferences */
-	prefs_set_int("conversion_target_format", TARGET_FORMAT_MP3);
+
+    /* New conversion preferences */
+    prefs_set_int("conversion_target_format", TARGET_FORMAT_MP3);
+
+    /* ReplayGain prefs */
+    prefs_set_int("replaygain_offset", 0);
+    prefs_set_int("replaygain_mode_album_priority", TRUE);
 }
 
 /* Initialize default variable-length list entries */
@@ -1050,6 +1053,7 @@ static void cleanup_keys()
     prefs_set_string("conversion_enable", NULL);
     prefs_set_string("export_template", NULL);
     prefs_set_string("filename_format", NULL);
+    prefs_set_string("write_extended_info", NULL);
 
     /* sp_created_cond renamed to sp_added_cond */
     for (i = 0; i < SORT_TAB_MAX; i++)
