@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: prefs.h 1596 2007-06-26 14:33:01Z dforsi $
+|  $Id$
 */
 
 #ifndef __PREFS_H__
@@ -35,7 +35,7 @@
 #endif
 
 #include <gtk/gtk.h>
-#include "prefs_window.h"
+#include "sort_window.h"
 #include "display.h"
 
 
@@ -58,6 +58,11 @@ extern const gchar *KEY_MANUAL_SYNCDIR;
 extern const gchar *KEY_DISPLAY_COVERART;
 
 /* New prefs backend. Will replace the stuff above */
+enum conv_target_format
+{
+	TARGET_FORMAT_MP3 = 0,
+	TARGET_FORMAT_AAC,
+};
 
 /* 
  * Wrapper data types for temp preferences
@@ -141,6 +146,7 @@ gboolean temp_prefs_subkey_exists (TempPrefs *temp_prefs,
  * Temp prefs functions
  */
 TempPrefs *temp_prefs_create (void);
+void temp_prefs_copy_prefs (TempPrefs *temp_prefs);
 TempPrefs *temp_prefs_load (const gchar *filename, GError **error);
 gboolean temp_prefs_save (TempPrefs *temp_prefs,
 			  const gchar *filename,
