@@ -24,7 +24,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: repository.c 2126 2008-10-01 14:40:48Z jcsjcs $
+|  $Id$
 */
 
 /* This file provides functions for the edit repositories/playlist
@@ -331,7 +331,6 @@ static gboolean finish_editable_storage (RepWin *repwin,
    prefs system. If values differ, store @val for @key in
    @repwin->temp_prefs, otherwise remove a possibly existing entry
    @key in @repwin->temp_prefs. */
-/* Attention: g_frees() @key for you */
 static void finish_int_storage (RepWin *repwin,
 				gchar *key, gint val)
 {
@@ -358,7 +357,6 @@ static void finish_int_storage (RepWin *repwin,
 	temp_prefs_remove_key (repwin->temp_prefs, key);
     }
     update_buttons (repwin);
-    g_free (key);
 }
 
 
@@ -420,6 +418,8 @@ static void sync_playlist_mode_none_toggled (GtkToggleButton *togglebutton,
 			    SYNC_PLAYLIST_MODE_NONE);
 	update_buttons (repwin);
     }
+
+    g_free (key);
 }
 
 
@@ -440,6 +440,8 @@ static void sync_playlist_mode_manual_toggled (GtkToggleButton *togglebutton,
 			    SYNC_PLAYLIST_MODE_MANUAL);
 	update_buttons (repwin);
     }
+
+    g_free (key);
 }
 
 
@@ -478,6 +480,8 @@ static void standard_itdb_checkbutton_toggled (GtkToggleButton *togglebutton,
     key = get_itdb_prefs_key (repwin->itdb_index, keybase);
     finish_int_storage (repwin, key,
 			gtk_toggle_button_get_active (togglebutton));
+
+    g_free (key);
 }
 
 
@@ -507,10 +511,12 @@ static void standard_playlist_checkbutton_toggled (GtkToggleButton *togglebutton
 	    temp_prefs_set_int (repwin->extra_prefs, key, active);
 
 	update_buttons (repwin);
+	g_free (key);
 	return;
     }
 	
     finish_int_storage (repwin, key, active);
+    g_free (key);
 }
 
 /* delete_repository_button was clicked */
@@ -1956,6 +1962,7 @@ void repository_edit (iTunesDB *itdb, Playlist *playlist)
     repwin->window = gtkpod_xml_get_widget (repwin->xml,
 					    "repository_window");
     g_return_if_fail (repwin->window);
+    gtk_window_set_transient_for (GTK_WINDOW (repwin->window), GTK_WINDOW (gtkpod_window));
 
     repwins = g_list_append (repwins, repwin);
 
@@ -2368,7 +2375,7 @@ static void cr_mountpoint_button_clicked (GtkButton *button,
     g_return_if_fail (cr);
 
     old_dir = gtk_entry_get_text (
-	GTK_ENTRY (GET_WIDGET (MOUNTPOINT_ENTRY)));
+	GTK_ENTRY (GET_WIDGET (CRW_MOUNTPOINT_ENTRY)));
 
     new_dir = fileselection_get_file_or_dir (
 	_("Select mountpoint"),
@@ -2377,7 +2384,7 @@ static void cr_mountpoint_button_clicked (GtkButton *button,
 
     if (new_dir)
     {
-	gtk_entry_set_text (GTK_ENTRY (GET_WIDGET (MOUNTPOINT_ENTRY)),
+	gtk_entry_set_text (GTK_ENTRY (GET_WIDGET (CRW_MOUNTPOINT_ENTRY)),
 			    new_dir);
 	g_free (new_dir);
     }
@@ -2394,7 +2401,7 @@ static void cr_backup_button_clicked (GtkButton *button,
     g_return_if_fail (cr);
 
     old_backup = gtk_entry_get_text (
-	GTK_ENTRY (GET_WIDGET (BACKUP_ENTRY)));
+	GTK_ENTRY (GET_WIDGET (CRW_BACKUP_ENTRY)));
 
     new_backup = fileselection_get_file_or_dir (
 	_("Set backup file"),
@@ -2403,7 +2410,7 @@ static void cr_backup_button_clicked (GtkButton *button,
 
     if (new_backup)
     {
-	gtk_entry_set_text (GTK_ENTRY (GET_WIDGET (BACKUP_ENTRY)),
+	gtk_entry_set_text (GTK_ENTRY (GET_WIDGET (CRW_BACKUP_ENTRY)),
 			    new_backup);
 	g_free (new_backup);
     }
@@ -2422,7 +2429,7 @@ static void cr_local_path_button_clicked (GtkButton *button,
     g_return_if_fail (cr);
 
     old_path = gtk_entry_get_text (
-	GTK_ENTRY (GET_WIDGET (LOCAL_PATH_ENTRY)));
+	GTK_ENTRY (GET_WIDGET (CRW_LOCAL_PATH_ENTRY)));
 
     new_path = fileselection_get_file_or_dir (
 	_("Set local repository file"),
@@ -2431,7 +2438,7 @@ static void cr_local_path_button_clicked (GtkButton *button,
 
     if (new_path)
     {
-	gtk_entry_set_text (GTK_ENTRY (GET_WIDGET (LOCAL_PATH_ENTRY)),
+	gtk_entry_set_text (GTK_ENTRY (GET_WIDGET (CRW_LOCAL_PATH_ENTRY)),
 			    new_path);
 	g_free (new_path);
     }
@@ -2473,6 +2480,8 @@ static void create_repository (RepWin *repwin1)
 					"create_repository_window");
 
     g_return_if_fail (cr->window);
+    gtk_window_set_transient_for (GTK_WINDOW (cr->window), GTK_WINDOW (repwin1->window));
+
 
     /* Window control */
     g_signal_connect (GET_WIDGET (CRW_CANCEL_BUTTON), "clicked",
