@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: sort_window.c 2087 2008-08-04 13:12:23Z jcsjcs $
+|  $Id$
 */
 
 #include <stdio.h>
@@ -266,13 +266,14 @@ void sort_window_create (void)
 
 		/* associate tm_listed_order with sort_window */
 		g_object_set_data (G_OBJECT (sort_window), "tm_listed_order", tm_listed_order);
-			
+
 		tooltips = gtk_tooltips_new ();
 		gtk_tooltips_set_tip (tooltips, w, _("You can also use the table headers, but this allows you to sort according to a column that is not displayed."), NULL);
 
 		sort_window_update ();
 
 		sort_window_show_hide_tooltips ();
+	    gtk_window_set_transient_for (GTK_WINDOW (sort_window), GTK_WINDOW (gtkpod_window));
 		gtk_widget_show (sort_window);
     }
 }
@@ -487,6 +488,12 @@ static void sort_window_set ()
     /* update compare string keys */
     compare_string_fuzzy_generate_keys ();
 
+    /* if case sensitive has changed, rebuild sortkeys */
+    if (temp_prefs_get_int_value(sort_temp_prefs, "case_sensitive", &val))
+    {
+	st_rebuild_sortkeys ();
+	temp_prefs_remove_key (sort_temp_prefs, "case_sensitive");
+    }
     /* if sort type has changed, initialize display */
     if (temp_prefs_get_int_value(sort_temp_prefs, "pm_sort", &val))
     {
